/*

border_regressions.do

Creates Table 10.
 
Supply effect regressions for the sample consisting of municipalities whose share straight is >= 0.5. In addition, it excludes parcels that have a price per sf equal to zero.  

Last Modified 1/8/2014

*/

/*Set up*/
clear all
set matsize 3000
set more off
quietly capture log close

// REPLACE THIS WITH THE DIRECTORY CONTAINING THE DO-FILES AND DATA:
cd "mydirectory"


log using border_regressions.log, text replace

use border_data, clear

/*Sample: sample2 is >= 0.5*/
global sample (straight_new_dis_noc1km >= 0.5) 
global s sample2

/*Control variables*/
global parcel1 land landsq log_cbd_dist log_cbd_dist2 us990_tri us990_tri_5km us990_tri_10km
global own_demo own_black own_asian own_edu_hs own_edu_bs own_med_hh_inc 
global parcel2 emp94 emp94_5km emp94_10km dev90 dev90_5km dev90_10km 

/*Share of dry land and urban dry land*/
foreach x in 100 250 {
	gen share_dry`x'm = 1 - share_water`x'm
	gen share_udry`x'm = share_urban`x'm / share_dry`x'm
	replace share_udry`x'm = 0 if share_urban`x'm == 0 & share_dry`x'm == 0 
}

**************************************************************************************************************
* REGRESSIONS
**************************************************************************************************************

drop ones count
egen border = group(border_id_str)
xtset border

foreach depvar in share_urban share_udry {

	/*Regression 1*/ 
	preserve
	gen ones = 1
	bysort border : egen count = count(ones)
	drop if count == 1
	drop ones count	
	local reg = 1 
	foreach x in 100 250 {
		disp "Regression `reg' for dependent variable `depvar'`x'm and sample $sample"
		xi: xtreg `depvar'`x'm own_wrluri if $sample, fe robust 
		matrix b = e(b) 
		matrix v = e(V)
		local b_`reg'_`depvar'_`x' = b[1,1]
		local sd_`reg'_`depvar'_`x' = sqrt(v[1,1])
		local obs_`reg'_`depvar'_`x' = `e(N)'
		local g_`reg'_`depvar'_`x' = `e(N_g)'
		local t_`reg'_`depvar'_`x' = `b_`reg'_`depvar'_`x'' / `sd_`reg'_`depvar'_`x''
		local p_`reg'_`depvar'_`x' = 2 * ttail(e(df_r), abs(`t_`reg'_`depvar'_`x''))
	}
	local fe_`reg'_`depvar' = 1 // fixed effects
	local c1_`reg'_`depvar' = 0 // per pupil expenditures
	local c2_`reg'_`depvar' = 0 // property taxes 
	local c3_`reg'_`depvar' = 0 // demographics
	local c4_`reg'_`depvar' = 0 // parcel I controls
	local c5_`reg'_`depvar' = 0 // parcel II controls
	restore
	
	/*Regression 2*/ 
	preserve
	drop if missing(pp_expend, ptax)
	gen ones = 1
	bysort border : egen count = count(ones)
	drop if count == 1
	drop ones count	
	local reg = 2
	foreach x in 100 250 {
		disp "Regression `reg' for dependent variable `depvar'`x'm and sample $sample"
		xi: xtreg `depvar'`x'm own_wrluri pp_expend ptax if $sample, fe robust 
		matrix b = e(b) 
		matrix v = e(V)
		local b_`reg'_`depvar'_`x' = b[1,1]
		local sd_`reg'_`depvar'_`x' = sqrt(v[1,1])
		local obs_`reg'_`depvar'_`x' = `e(N)'
		local g_`reg'_`depvar'_`x' = `e(N_g)'
		local t_`reg'_`depvar'_`x' = `b_`reg'_`depvar'_`x'' / `sd_`reg'_`depvar'_`x''
		local p_`reg'_`depvar'_`x' = 2 * ttail(e(df_r), abs(`t_`reg'_`depvar'_`x''))
	}
	local fe_`reg'_`depvar' = 1 // fixed effects
	local c1_`reg'_`depvar' = 1 // per pupil expenditures
	local c2_`reg'_`depvar' = 1 // property taxes 
	local c3_`reg'_`depvar' = 0 // demographics
	local c4_`reg'_`depvar' = 0 // parcel I controls
	local c5_`reg'_`depvar' = 0 // parcel II controls
	restore

	/*Regression 3*/ 
	preserve
	drop if missing(pp_expend, ptax, own_black, own_asian, own_edu_hs, own_edu_bs, own_med_hh_inc)
	gen ones = 1
	bysort border : egen count = count(ones)
	drop if count == 1
	drop ones count	
	local reg = 3
	foreach x in 100 250 {
		disp "Regression `reg' for dependent variable `depvar'`x'm and sample $sample"
		xi: xtreg `depvar'`x'm own_wrluri pp_expend ptax $own_demo if $sample, fe robust 
		matrix b = e(b) 
		matrix v = e(V)
		local b_`reg'_`depvar'_`x' = b[1,1]
		local sd_`reg'_`depvar'_`x' = sqrt(v[1,1])
		local obs_`reg'_`depvar'_`x' = `e(N)'
		local g_`reg'_`depvar'_`x' = `e(N_g)'
		local t_`reg'_`depvar'_`x' = `b_`reg'_`depvar'_`x'' / `sd_`reg'_`depvar'_`x''
		local p_`reg'_`depvar'_`x' = 2 * ttail(e(df_r), abs(`t_`reg'_`depvar'_`x''))
	}
	local fe_`reg'_`depvar' = 1 // fixed effects
	local c1_`reg'_`depvar' = 1 // per pupil expenditures
	local c2_`reg'_`depvar' = 1 // property taxes 
	local c3_`reg'_`depvar' = 1 // demographics
	local c4_`reg'_`depvar' = 0 // parcel I controls
	local c5_`reg'_`depvar' = 0 // parcel II controls
	restore
	
	/*Regression 4*/ 
	preserve
	drop if missing(pp_expend, ptax, own_black, own_asian, own_edu_hs, own_edu_bs, own_med_hh_inc, ///
		land, landsq, log_cbd_dist, log_cbd_dist2, us990_tri, us990_tri_5km, us990_tri_10km)
	gen ones = 1
	bysort border : egen count = count(ones)
	drop if count == 1
	drop ones count	
	local reg = 4
	foreach x in 100 250 {
		disp "Regression `reg' for dependent variable `depvar'`x'm and sample $sample"
		xi: xtreg `depvar'`x'm own_wrluri pp_expend ptax $own_demo $parcel1 if $sample, fe robust 
		matrix b = e(b) 
		matrix v = e(V)
		local b_`reg'_`depvar'_`x' = b[1,1]
		local sd_`reg'_`depvar'_`x' = sqrt(v[1,1])
		local obs_`reg'_`depvar'_`x' = `e(N)'
		local g_`reg'_`depvar'_`x' = `e(N_g)'
		local t_`reg'_`depvar'_`x' = `b_`reg'_`depvar'_`x'' / `sd_`reg'_`depvar'_`x''
		local p_`reg'_`depvar'_`x' = 2 * ttail(e(df_r), abs(`t_`reg'_`depvar'_`x''))
	}
	local fe_`reg'_`depvar' = 1 // fixed effects
	local c1_`reg'_`depvar' = 1 // per pupil expenditures
	local c2_`reg'_`depvar' = 1 // property taxes 
	local c3_`reg'_`depvar' = 1 // demographics
	local c4_`reg'_`depvar' = 1 // parcel I controls
	local c5_`reg'_`depvar' = 0 // parcel II controls
	restore
	
	/*Regression 5*/ 
	preserve
	drop if missing(pp_expend, ptax, own_black, own_asian, own_edu_hs, own_edu_bs, own_med_hh_inc, ///
		emp94, emp94_5km, emp94_10km, dev90, dev90_5km, dev90_10km)
	gen ones = 1
	bysort border : egen count = count(ones)
	drop if count == 1
	drop ones count	
	local reg = 5
	foreach x in 100 250 {
		disp "Regression `reg' for dependent variable `depvar'`x'm and sample $sample"
		xi: xtreg `depvar'`x'm own_wrluri pp_expend ptax $own_demo $parcel2 if $sample, fe robust 
		matrix b = e(b) 
		matrix v = e(V)
		local b_`reg'_`depvar'_`x' = b[1,1]
		local sd_`reg'_`depvar'_`x' = sqrt(v[1,1])
		local obs_`reg'_`depvar'_`x' = `e(N)'
		local g_`reg'_`depvar'_`x' = `e(N_g)'
		local t_`reg'_`depvar'_`x' = `b_`reg'_`depvar'_`x'' / `sd_`reg'_`depvar'_`x''
		local p_`reg'_`depvar'_`x' = 2 * ttail(e(df_r), abs(`t_`reg'_`depvar'_`x''))
	}
	local fe_`reg'_`depvar' = 1 // fixed effects
	local c1_`reg'_`depvar' = 1 // per pupil expenditures
	local c2_`reg'_`depvar' = 1 // property taxes 
	local c3_`reg'_`depvar' = 1 // demographics
	local c4_`reg'_`depvar' = 0 // parcel I controls
	local c5_`reg'_`depvar' = 1 // parcel II controls
	restore
	
	/*Regression 6*/ 
	preserve
	drop if missing(pp_expend, ptax, own_black, own_asian, own_edu_hs, own_edu_bs, own_med_hh_inc, ///
		land, landsq, log_cbd_dist, log_cbd_dist2, us990_tri, us990_tri_5km, us990_tri_10km, ///
		emp94, emp94_5km, emp94_10km, dev90, dev90_5km, dev90_10km)
	gen ones = 1
	bysort border : egen count = count(ones)
	drop if count == 1
	drop ones count	
	local reg = 6
	foreach x in 100 250 {
		disp "Regression `reg' for dependent variable `depvar'`x'm and sample $sample"
		xi: xtreg `depvar'`x'm own_wrluri pp_expend ptax $own_demo $parcel1 $parcel2 ///
			if $sample, fe robust 
		matrix b = e(b) 
		matrix v = e(V)
		local b_`reg'_`depvar'_`x' = b[1,1]
		local sd_`reg'_`depvar'_`x' = sqrt(v[1,1])
		local obs_`reg'_`depvar'_`x' = `e(N)'
		local g_`reg'_`depvar'_`x' = `e(N_g)'
		local t_`reg'_`depvar'_`x' = `b_`reg'_`depvar'_`x'' / `sd_`reg'_`depvar'_`x''
		local p_`reg'_`depvar'_`x' = 2 * ttail(e(df_r), abs(`t_`reg'_`depvar'_`x''))
	}
	local fe_`reg'_`depvar' = 1 // fixed effects
	local c1_`reg'_`depvar' = 1 // per pupil expenditures
	local c2_`reg'_`depvar' = 1 // property taxes 
	local c3_`reg'_`depvar' = 1 // demographics
	local c4_`reg'_`depvar' = 1 // parcel I controls
	local c5_`reg'_`depvar' = 1 // parcel II controls
	restore
}

**************************************************************************************************************
* BUILD OUTPUT TABLE
**************************************************************************************************************

/*Generate variables for table*/
clear
gen depvar = ""
gen temp1 = ""
gen temp2 = ""
forvalues x = 1/6 {
	gen reg_`x' = . 
}

/*Set the number of observations*/
set obs 19

/*Fill in dependent variable labels*/
#delimit ;
local list1 `""Share urban (100m)" "Share urban (250m)" "Share urban/share dry land (100m)" 
	"Share urban/share dry land (250m)""';
local list2 `""share_urban" "share_urban" "share_udry" "share_udry""';
local list3 `""100" "250" "100" "250""';
#delimit cr
local i = 1 
forvalues x = 2(3)11 { 
	local name1 : word `i' of `list1' 
	local name2 : word `i' of `list2'
	local name3 : word `i' of `list3'
	replace depvar = "`name1'" in `x'
	replace temp1 = "`name2'" in `x'
	replace temp2 = "`name3'" in `x' 
	local i = `i' + 1
}

/*Fill in control labels*/
#delimit ;
local list1 `""Border pair FE" "Per pupil expenditures" "Property taxes per acre" "Demographics"
	"Municipal controls I"  "Municipal controls II""';
local list2 `""fe" "c1" "c2" "c3" "c4" "c5""';
#delimit cr
local i = 1 
forvalues x = 14/19 {
	local name1 : word `i' of `list1' 
	local name2 : word `i' of `list2'
	replace depvar = "`name1'" in `x' 
	replace temp1 = "`name2'" in `x' 
	local i = `i' + 1
}

/*Fill in the table*/
local N = _N 
forvalues reg = 1/6 {
	foreach depvar in share_urban share_udry {
		foreach dist in 100 250 {
			forvalues x = 1/`N' {
				if "`dist'" == temp2[`x'] & "`depvar'" == temp1[`x'] {
					local y = `x' + 1
					local z = `y' + 1
					replace reg_`reg' = `b_`reg'_`depvar'_`dist'' in `x' 
					replace reg_`reg' = `sd_`reg'_`depvar'_`dist'' in `y' 
					replace reg_`reg' = `g_`reg'_`depvar'_`dist'' in `z' 
				}
			}
		}
		foreach control in fe c1 c2 c3 c4 c5 {
			forvalues x = 1/`N' {
				if "`control'" == temp1[`x'] {
					replace reg_`reg' = ``control'_`reg'_`depvar'' in `x' 
				}
			}
		}
	}
}

/*Convert variables to strings and round*/
forvalues reg = 1/6 {
	tostring reg_`reg', replace force format(%10.2f)
	foreach x in 4 7 10 13 14 15 16 17 18 19 {
		replace reg_`reg' = subinstr(reg_`reg'[`x'], ".00", "", .) in `x' 
	}
}

/*Add in significance stars*/
local N = _N
forvalues reg = 1/6 {
	foreach depvar in share_urban share_udry {
		foreach dist in 100 250 {
			forvalues x = 1/`N' {
				if "`dist'" == temp2[`x'] & "`depvar'" == temp1[`x'] {
					local y = `x' + 1
					local sd = reg_`reg'[`y']
					local p = `p_`reg'_`depvar'_`dist''
					if `p' > 0.1 {
						capture replace reg_`reg' = "(" + "`sd'" + ")" in `y' 
					}
					if `p' <= 0.1 & `p' > 0.05 {
						local star "*"
						capture replace reg_`reg' = "(" + "`sd'" + ")" + "`star'" in `y' 
					}
					if `p' <= 0.05 & `p' > 0.01 {
						local star "**"
						capture replace reg_`reg' = "(" + "`sd'" + ")" + "`star'" in `y' 
					}	
					if `p' <= 0.01 { 
						local star "***"
						capture replace reg_`reg' = "(" + "`sd'" + ")" + "`star'" in `y' 
					}					
				}
			}
		}
	}
}

/*Add in column titles*/
local list1 `""(1)" "(2)" "(3)" "(4)" "(5)" "(6)""'
local i = 1 
forvalues reg = 1/6 {
	forvalues x = 1/1 {
		local name1 : word `i' of `list1' 
		replace reg_`reg' = "`name1'" in `x' 
		local i = `i' + 1
	}
}	

/*Replace controls = 1 with controls = Y*/
local N = _N
forvalues reg = 1/6 {
	forvalues x = 14/`N' {
		if reg_`reg'[`x'] == "1" {
			replace reg_`reg' = "Y" in `x' 
		}
		if reg_`reg'[`x'] == "0" {
			replace reg_`reg' = "" in `x' 
		}
	}
}	

/*Save file*/
drop temp*
export excel using table10_supplyeffect.xls, replace

log close
