/*

parcel_regressions.do

Creates Tables 2-9, A2 and A3.

Last Modified 1/8/2014

*/

/*Set up*/
clear all
set matsize 3000
set more off
quietly capture log close

// Replace this with the directory containing the do-files and data:
cd "mydirectory"
log using parcel_regressions.log, text replace


**************************************************************************************************************
* Table 2 - Own-lot Effect regressions
**************************************************************************************************************

**************************************************************************************************************
* LOOP OVER REGULATION VARIABLES, STRAIGHT BORDER VARIABLES, AND SAMPLE RANGES
**************************************************************************************************************

foreach regvar in own_wrluri own_llla own_dri own_osi {
	foreach straight in 500m 1km {
		foreach yr in 00 {

			********************************************************************************************
			* CREATE LISTS OF CONTROL VARIABLES
			********************************************************************************************

			global controls1 own_mean_pp_expend own_mean_ptax
			global controls2 own_black own_asian own_edu_hs own_edu_bs own_med_hh_inc 
			global controls3 land landsq log_cbd_dist log_cbd_dist2 us990_tri us990_tri_5km us990_tri_10km
			global controls4 emp94 emp94_5km emp94_10km dev90 dev90_5km dev90_10km 

			/*Distance thresholds*/
			global dist1 = 100
			global dist3 = 0.5
			global dist5 = 0.1

			********************************************************************************************
			* LOAD DATA AND IMPOSE SAMPLE RESTRICTIONS
			********************************************************************************************

			use parcel_data, clear
         
			/*Drop observations that are missing the regulation variable of interest*/
			drop if `regvar' == . 

			/*Restrict sample to straight borders*/
			drop if straight_new_dis_noc`straight' == 0 

			/*Restrict dates in sample*/
			drop if year_lt`yr' > 0

			/*Drop extraneous quarterly dummies*/
			if `yr' == 00 {
				drop q19832 - q19994
			}
			if `yr' == 90 {
				drop q19832 - q19894
			}
			
			/*Create flags to identify borders with parcels at different distances (e.g. border_straight1 
			tags all parcels attached to borders for which some parcel is less than $dist1 from a straight 
      line border)*/
			sort border_code nbr_dist
			by border_code : egen min_dist_straight = min(nbr_dist) if straight_new_dis_noc`straight' == 1
			foreach x in 1 3 5 { 
				gen border_straight = (min_dist_straight < ${dist`x'})
				by border_code : egen border_straight`x' = max(border_straight)
				drop border_straight
			}
			drop min_dist_straight

			/*Set up border code fixed effects*/
			xtset border_code
         
			********************************************************************************************
			* REGRESSIONS
			********************************************************************************************

			/*Regression 1*/
			local reg = 1
			foreach x in 1 3 5 {
				disp "Regression `reg' for year `yr' and sample `straight'"
				disp "Distance = ${dist`x'}"
				local if4sample "(nbr_dist < ${dist`x'}) & (border_straight`x' == 1)"
				xi: xtreg pricepersflandgross `regvar' q* if `if4sample', fe robust cluster ///
              (border_code)
				matrix b = e(b)
				matrix v = e(V)
				local b_`reg'_`yr'_`regvar'_`straight'_`x' = round(b[1,1], 0.01)
				local sd_`reg'_`yr'_`regvar'_`straight'_`x' = round(sqrt(v[1,1]), 0.01)
				local obs_`reg'_`yr'_`regvar'_`straight'_`x' `e(N)'
				local g_`reg'_`yr'_`regvar'_`straight'_`x' `e(N_g)'
				local t_`reg'_`yr'_`regvar'_`straight'_`x' = `b_`reg'_`yr'_`regvar'_`straight'_`x'' / ///
              `sd_`reg'_`yr'_`regvar'_`straight'_`x''
				local p_`reg'_`yr'_`regvar'_`straight'_`x' = 2 * ttail(e(df_r), ///
                 abs(`t_`reg'_`yr'_`regvar'_`straight'_`x''))
			}
			local fe_`reg'_`yr'_`regvar'_`straight' = 1 // fixed effects
			local c1_`reg'_`yr'_`regvar'_`straight' = 1 // quarterly dummies
			local c2_`reg'_`yr'_`regvar'_`straight' = 0 // per pupil expenditures
			local c3_`reg'_`yr'_`regvar'_`straight' = 0 // property taxes
			local c4_`reg'_`yr'_`regvar'_`straight' = 0 // demographics
			local c5_`reg'_`yr'_`regvar'_`straight' = 0 // parcel I controls
			local c6_`reg'_`yr'_`regvar'_`straight' = 0 // parcel II controls
			
			/*Regression 2*/
			local reg = 2
			foreach x in 1 3 5 {
				disp "Regression `reg' for year `yr' and sample `straight'"
				disp "Distance = ${dist`x'}"
				local if4sample "(nbr_dist < ${dist`x'}) & (border_straight`x' == 1)"
				xi: xtreg pricepersflandgross `regvar' $controls1 q* if `if4sample', fe robust cluster ///
              (border_code)
				matrix b = e(b)
				matrix v = e(V)
				local b_`reg'_`yr'_`regvar'_`straight'_`x' = round(b[1,1], 0.01)
				local sd_`reg'_`yr'_`regvar'_`straight'_`x' = round(sqrt(v[1,1]), 0.01)
				local obs_`reg'_`yr'_`regvar'_`straight'_`x' `e(N)'
				local g_`reg'_`yr'_`regvar'_`straight'_`x' `e(N_g)'
				local t_`reg'_`yr'_`regvar'_`straight'_`x' = `b_`reg'_`yr'_`regvar'_`straight'_`x'' / ///
              `sd_`reg'_`yr'_`regvar'_`straight'_`x''
				local p_`reg'_`yr'_`regvar'_`straight'_`x' = 2 * ttail(e(df_r), ///
                 abs(`t_`reg'_`yr'_`regvar'_`straight'_`x''))
			}
			local fe_`reg'_`yr'_`regvar'_`straight' = 1 // fixed effects
			local c1_`reg'_`yr'_`regvar'_`straight' = 1 // quarterly dummies
			local c2_`reg'_`yr'_`regvar'_`straight' = 1 // per pupil expenditures
			local c3_`reg'_`yr'_`regvar'_`straight' = 1 // property taxes
			local c4_`reg'_`yr'_`regvar'_`straight' = 0 // demographics
			local c5_`reg'_`yr'_`regvar'_`straight' = 0 // parcel I controls
			local c6_`reg'_`yr'_`regvar'_`straight' = 0 // parcel II controls
			
			/*Regression 3*/
			local reg = 3
			foreach x in 1 3 5 {
				disp "Regression `reg' for year `yr' and sample `straight'"
				disp "Distance = ${dist`x'}"
				local if4sample "(nbr_dist < ${dist`x'}) & (border_straight`x' == 1)"
				xi: xtreg pricepersflandgross `regvar' $controls1 $controls2 q* if `if4sample', fe ///
              robust cluster (border_code)
				matrix b = e(b)
				matrix v = e(V)
				local b_`reg'_`yr'_`regvar'_`straight'_`x' = round(b[1,1], 0.01)
				local sd_`reg'_`yr'_`regvar'_`straight'_`x' = round(sqrt(v[1,1]), 0.01)
				local obs_`reg'_`yr'_`regvar'_`straight'_`x' `e(N)'
				local g_`reg'_`yr'_`regvar'_`straight'_`x' `e(N_g)'
				local t_`reg'_`yr'_`regvar'_`straight'_`x' = `b_`reg'_`yr'_`regvar'_`straight'_`x'' / ///
              `sd_`reg'_`yr'_`regvar'_`straight'_`x''
				local p_`reg'_`yr'_`regvar'_`straight'_`x' = 2 * ttail(e(df_r), ///
                 abs(`t_`reg'_`yr'_`regvar'_`straight'_`x''))
			}
			local fe_`reg'_`yr'_`regvar'_`straight' = 1 // fixed effects
			local c1_`reg'_`yr'_`regvar'_`straight' = 1 // quarterly dummies
			local c2_`reg'_`yr'_`regvar'_`straight' = 1 // per pupil expenditures
			local c3_`reg'_`yr'_`regvar'_`straight' = 1 // property taxes
			local c4_`reg'_`yr'_`regvar'_`straight' = 1 // demographics
			local c5_`reg'_`yr'_`regvar'_`straight' = 0 // parcel I controls
			local c6_`reg'_`yr'_`regvar'_`straight' = 0 // parcel II controls
			
			/*Regression 4*/
			local reg = 4
			foreach x in 1 3 5 {
				disp "Regression `reg' for year `yr' and sample `straight'"
				disp "Distance = ${dist`x'}"
				local if4sample "(nbr_dist < ${dist`x'}) & (border_straight`x' == 1)"
				xi: xtreg pricepersflandgross `regvar' $controls1 $controls2 $controls3 q* if ///
              `if4sample', fe robust cluster (border_code)
				matrix b = e(b)
				matrix v = e(V)
				local b_`reg'_`yr'_`regvar'_`straight'_`x' = round(b[1,1], 0.01)
				local sd_`reg'_`yr'_`regvar'_`straight'_`x' = round(sqrt(v[1,1]), 0.01)
				local obs_`reg'_`yr'_`regvar'_`straight'_`x' `e(N)'
				local g_`reg'_`yr'_`regvar'_`straight'_`x' `e(N_g)'
				local t_`reg'_`yr'_`regvar'_`straight'_`x' = `b_`reg'_`yr'_`regvar'_`straight'_`x'' / ///
              `sd_`reg'_`yr'_`regvar'_`straight'_`x''
				local p_`reg'_`yr'_`regvar'_`straight'_`x' = 2 * ttail(e(df_r), ///
                 abs(`t_`reg'_`yr'_`regvar'_`straight'_`x''))
			}
			local fe_`reg'_`yr'_`regvar'_`straight' = 1 // fixed effects
			local c1_`reg'_`yr'_`regvar'_`straight' = 1 // quarterly dummies
			local c2_`reg'_`yr'_`regvar'_`straight' = 1 // per pupil expenditures
			local c3_`reg'_`yr'_`regvar'_`straight' = 1 // property taxes
			local c4_`reg'_`yr'_`regvar'_`straight' = 1 // demographics
			local c5_`reg'_`yr'_`regvar'_`straight' = 1 // parcel I controls
			local c6_`reg'_`yr'_`regvar'_`straight' = 0 // parcel II controls
			
			/*Regression 5*/
			local reg = 5
			foreach x in 1 3 5 {
				disp "Regression `reg' for year `yr' and sample `straight'"
				disp "Distance = ${dist`x'}"
				local if4sample "(nbr_dist < ${dist`x'}) & (border_straight`x' == 1)"
				xi: xtreg pricepersflandgross `regvar' $controls1 $controls2 $controls4 q* if ///
              `if4sample', fe robust cluster (border_code)
				matrix b = e(b)
				matrix v = e(V)
				local b_`reg'_`yr'_`regvar'_`straight'_`x' = round(b[1,1], 0.01)
				local sd_`reg'_`yr'_`regvar'_`straight'_`x' = round(sqrt(v[1,1]), 0.01)
				local obs_`reg'_`yr'_`regvar'_`straight'_`x' `e(N)'
				local g_`reg'_`yr'_`regvar'_`straight'_`x' `e(N_g)'
				local t_`reg'_`yr'_`regvar'_`straight'_`x' = `b_`reg'_`yr'_`regvar'_`straight'_`x'' / ///
              `sd_`reg'_`yr'_`regvar'_`straight'_`x''
				local p_`reg'_`yr'_`regvar'_`straight'_`x' = 2 * ttail(e(df_r), ///
                 abs(`t_`reg'_`yr'_`regvar'_`straight'_`x''))
			}
			local fe_`reg'_`yr'_`regvar'_`straight' = 1 // fixed effects
			local c1_`reg'_`yr'_`regvar'_`straight' = 1 // quarterly dummies
			local c2_`reg'_`yr'_`regvar'_`straight' = 1 // per pupil expenditures
			local c3_`reg'_`yr'_`regvar'_`straight' = 1 // property taxes
			local c4_`reg'_`yr'_`regvar'_`straight' = 1 // demographics
			local c5_`reg'_`yr'_`regvar'_`straight' = 0 // parcel I controls
			local c6_`reg'_`yr'_`regvar'_`straight' = 1 // parcel II controls
         
			/*Regression 6*/
			local reg = 6
			foreach x in 1 3 5 {
				disp "Regression `reg' for year `yr' and sample `straight'"
				disp "Distance = ${dist`x'}"
				local if4sample "(nbr_dist < ${dist`x'}) & (border_straight`x' == 1)"
				xi: xtreg pricepersflandgross `regvar' $controls1 $controls2 $controls3 $controls4 ///
              q* if `if4sample', fe robust cluster (border_code)
				matrix b = e(b)
				matrix v = e(V)
				local b_`reg'_`yr'_`regvar'_`straight'_`x' = round(b[1,1], 0.01)
				local sd_`reg'_`yr'_`regvar'_`straight'_`x' = round(sqrt(v[1,1]), 0.01)
				local obs_`reg'_`yr'_`regvar'_`straight'_`x' `e(N)'
				local g_`reg'_`yr'_`regvar'_`straight'_`x' `e(N_g)'
				local t_`reg'_`yr'_`regvar'_`straight'_`x' = `b_`reg'_`yr'_`regvar'_`straight'_`x'' / ///
              `sd_`reg'_`yr'_`regvar'_`straight'_`x''
				local p_`reg'_`yr'_`regvar'_`straight'_`x' = 2 * ttail(e(df_r), ///
                 abs(`t_`reg'_`yr'_`regvar'_`straight'_`x''))
			}
			local fe_`reg'_`yr'_`regvar'_`straight' = 1 // fixed effects
			local c1_`reg'_`yr'_`regvar'_`straight' = 1 // quarterly dummies
			local c2_`reg'_`yr'_`regvar'_`straight' = 1 // per pupil expenditures
			local c3_`reg'_`yr'_`regvar'_`straight' = 1 // property taxes
			local c4_`reg'_`yr'_`regvar'_`straight' = 1 // demographics
			local c5_`reg'_`yr'_`regvar'_`straight' = 1 // parcel I controls
			local c6_`reg'_`yr'_`regvar'_`straight' = 1 // parcel II controls
		}
	}
}

**************************************************************************************************************
* BUILD OUTPUT TABLE
**************************************************************************************************************

/*Generate variables for table*/
clear
gen distance = ""
gen temp1 = ""
gen temp2 = ""
gen temp3 = ""
foreach x in 1_00 2_00 3_00 4_00 5_00 6_00 {
	gen reg_`x' = . 
}

/*Set the number of observations*/
set obs 33

/*Fill in regulation variable labels*/
local list1 `""WRLURI 1km" "WRLURI 500m" "LLLA 1km" "DRI 1km" "OSI 1km""'
local i = 1
foreach x in 1 11 15 19 23 {
	local name1 : word `i' of `list1'
	replace distance = "`name1'" in `x'
	local i = `i' + 1
}

/*Fill in temp1 distance and control labels*/
local list1 `""all" "dist < 0.5" "dist < 0.1" "dist < 0.1" "dist < 0.1" "dist < 0.1" "dist < 0.1""'
local list2 `""1" "3" "5" "5" "5" "5" "5""'
local i = 1
foreach x in 2 5 8 12 16 20 24 {
	local name1 : word `i' of `list1' 
	local name2 : word `i' of `list2' 
	replace distance = "`name1'" in `x' 
	replace temp1 = "`name2'" in `x' 
	local i = `i' + 1
}

/*Fill in temp2 to define straight border samples*/
local list1 `""1km" "1km" "1km" "500m" "1km" "1km" "1km""'
local i = 1
foreach x in 2 5 8 12 16 20 24 {
	local name1 : word `i' of `list1'
	replace temp2 = "`name1'" in `x' 
	local i = `i' + 1
}

/*Fill in temp3 to define regulation variables*/
local list1 `""own_wrluri" "own_wrluri" "own_wrluri" "own_wrluri" "own_llla" "own_dri" "own_osi""'
local i = 1
foreach x in 2 5 8 12 16 20 24 {
	local name1 : word `i' of `list1'
	replace temp3 = "`name1'" in `x' 
	local i = `i' + 1
}

/*Fill in control labels*/
#delimit ;
local list3 `""Border pair FE" "Quarter dummies" "Per pupil expenditures" "Property taxes per acre" 
  "Demographics" "Parcel controls I" "Parcel controls II""';
#delimit cr
local list4 `""fe" "c1" "c2" "c3" "c4" "c5" "c6""'
local i = 1
forvalues x = 27/33 {
	local name3 : word `i' of `list3' 
	local name4 : word `i' of `list4'
	replace distance = "`name3'" in `x' 
	replace temp1 = "`name4'" in `x' 
	local i = `i' + 1 
}

/*Fill in the table*/
local N = _N
forvalues reg = 1/6 {
	foreach straight in 500m 1km {
		foreach regvar in own_wrluri own_llla own_dri own_osi {
			foreach yr in 00 {
				foreach dist in 1 3 5 {
					forvalues x = 1/`N' {
						if "`dist'" == temp1[`x'] & "`straight'" == temp2[`x'] & ///
                    "`regvar'" == temp3[`x'] {
							local y = `x' + 1
							local z = `x' + 2
							capture replace reg_`reg'_`yr' = ///
                       `b_`reg'_`yr'_`regvar'_`straight'_`dist'' in `x' 
							capture replace reg_`reg'_`yr' = ///
                       `sd_`reg'_`yr'_`regvar'_`straight'_`dist'' in `y' 
							capture replace reg_`reg'_`yr' = ///
                       `obs_`reg'_`yr'_`regvar'_`straight'_`dist'' in `z' 
						}
					}
				}
				foreach control in fe c1 c2 c3 c4 c5 c6 {
					forvalues x = 1/`N' {
						if "`control'" == temp1[`x'] {
							capture replace reg_`reg'_`yr' = ///
                       ``control'_`reg'_`yr'_`regvar'_`straight'' in `x' 
						}
					}
				}
			}
		}
	}
}	

/*Convert variables to strings and round*/
foreach x in 1_00 2_00 3_00 4_00 5_00 6_00 {
	tostring reg_`x', replace force format(%10.2f)
	foreach y in 4 7 10 14 18 22 26 27 28 29 30 31 32 33 {
		replace reg_`x' = subinstr(reg_`x'[`y'], ".00", "", .) in `y' 
	}
}

/*Add in group (border) observation counts and significance stars*/
local N = _N
forvalues reg = 1/6 {
	local yr 00
	foreach straight in 500m 1km {
		foreach regvar in own_wrluri own_llla own_dri own_osi {
			foreach dist in 1 3 5 {
				forvalues x = 1/`N' {
					if "`dist'" == temp1[`x'] & "`straight'" == temp2[`x'] & ///
                 "`regvar'" == temp3[`x'] {
						local y = `x' + 1
						local z = `x' + 2
						local sd = reg_`reg'_`yr'[`y']
						local p = `p_`reg'_`yr'_`regvar'_`straight'_`dist''
						if `p' > 0.1 {
							capture replace reg_`reg'_`yr' = ///
                       "(" + "`sd'" + ")" in `y' 
						}
						if `p' <= 0.1 & `p' > 0.05 {
							local star "*"
							capture replace reg_`reg'_`yr' = ///
                       "(" + "`sd'" + ")" + "`star'" in `y' 
						}
						if `p' <= 0.05 & `p' > 0.01 {
							local star "**"
							capture replace reg_`reg'_`yr' = ///
                       "(" + "`sd'" + ")" + "`star'" in `y' 
						}	
						if `p' <= 0.01 { 
							local star "***"
							capture replace reg_`reg'_`yr' = ///
                       "(" + "`sd'" + ")" + "`star'" in `y' 
						}					
						local obs = reg_`reg'_`yr'[`z']
						capture replace reg_`reg'_`yr' = "`obs'" + "/" + ///
                    "`g_`reg'_`yr'_`regvar'_`straight'_`dist''" in `z' 
					}
				}
			}
		}
	}
}

/*Replace missing values "." with spaces ""*/
foreach reg in 1_00 2_00 3_00 4_00 5_00 6_00 {
	replace reg_`reg' = "" if reg_`reg' == "."
}

/*Replace controls = 1 with controls = Y*/
local N = _N
foreach reg in 1_00 2_00 3_00 4_00 5_00 6_00 {
	forvalues x = 27/`N' {
		if reg_`reg'[`x'] == "1" {
			replace reg_`reg' = "Y" in `x' 
		}
		if reg_`reg'[`x'] == "0" {
			replace reg_`reg' = "" in `x' 
		}
	}
}

/*Save file*/
drop temp*
export excel using table2_ownlot_effect.xls, replace

**************************************************************************************************************
* Table 3 - Own-lot Effect regressions, robustness to sample timing and quarterly dummies
**************************************************************************************************************

use parcel_data, clear

/*Control variable lists*/
global parcel1 land landsq log_cbd_dist log_cbd_dist2 us990_tri us990_tri_5km us990_tri_10km
global parcel2 emp94 emp94_5km emp94_10km dev90 dev90_5km dev90_10km 
global own_demo own_black own_asian own_edu_hs own_edu_bs own_med_hh_inc 
global ex_demo d_int_black d_int_asian d_int_edu_hs d_int_edu_bs d_int_med_hh_inc 

/*Distance threshold*/
global dist = 0.1

/*Tag all parcels = 1 if they are attached to borders for which some parcel is less than $dist from a 
straight line border*/
sort border_code nbr_dist
by border_code : egen min_dist_straight = min(nbr_dist) if straight_new_dis_noc1km == 1
gen border_straight_temp = (min_dist_straight < $dist)
by border_code : egen border_straight = max(border_straight_temp) 
drop border_straight_temp min_dist_straight

/*Thresholds for bins*/
global bins "0.5 0.25 0.25"
global interior1 = real(word("$bins", 1))
global interior2 = real(word("$bins", 2))
global peripheral1 = real(word("$bins", 3))

/*Create indicator variables = 1 if parcel is in each interior bin & interact these with the regulation 
variable*/
gen int_flag = 1 if nbr_dist < $interior1 & nbr_dist > $interior2
replace int_flag = 0 if int_flag == . 
gen d_wrluri_int = d_wrluri * int_flag

/*Construct change in demograhics variables interacted with interior parcel dummy to use as demographic 
controls*/
foreach cat in black asian edu_hs edu_bs med_hh_inc {
	gen d_int_`cat' = (own_`cat' - nbr_`cat') * int_flag
}

/*Construct change in school/local finance variables interacted with interior parcel dummy*/
foreach var in pp_expend ptax {
	gen d_int_`var' = (own_mean_`var' - nbr_mean_`var') * int_flag
}

**************************************************************************************************************
* CONDITIONAL STATEMENTS AND GENERAL SAMPLE RESTRICTIONS
**************************************************************************************************************

/*Conditional statements*/
global if_own "(nbr_dist < $dist) & (border_straight == 1)"
global if_ex "((nbr_dist < $peripheral1) | (nbr_dist < $interior1 & nbr_dist > $interior2))"

/*General sample restrictions*/
drop if straight_new_dis_noc1km == 0 

xtset border_code

**************************************************************************************************************
* OWN-LOT EFFECT REGRESSIONS
**************************************************************************************************************

foreach yr in 00 03 {

	/*Restrict date range*/
	preserve
	drop if own_wrluri == . 
	drop if year_lt`yr' > 0 
	if `yr' == 00 {
		drop q19832 - q19994
	}
	if `yr' == 03 {
		drop q19832 - q20024
	}
	
	/*Regression A1*/
	local reg a1
	disp "Reg = `reg' and year = `yr'"
	xi: xtreg pricepersflandgross own_wrluri own_mean_pp_expend own_mean_ptax $own_demo ///
		q* if $if_own, fe robust cluster (border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`yr' = b[1,1]
	local sd_`reg'_`yr' = sqrt(v[1,1])
	local t_`reg'_`yr' = `b_`reg'_`yr'' / `sd_`reg'_`yr''
	local p_`reg'_`yr' = 2 * ttail(e(df_r), abs(`t_`reg'_`yr''))
	local fe_`reg' = 1 // fixed effects
	local c1_`reg' = 1 // quarterly dummies
	local c2_`reg' = 1 // per pupil expenditures 
	local c3_`reg' = 1 // property taxes 
	local c4_`reg' = 1 // demographics 
	local c5_`reg' = 0 // parcel I controls 
	local c6_`reg' = 0 // parcel II controls 

	/*Regression A2*/
	local reg a2
	disp "Reg = `reg' and year = `yr'"
	xi: xtreg pricepersflandgross own_wrluri own_mean_pp_expend own_mean_ptax $own_demo ///
		if $if_own, fe robust cluster (border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`yr' = b[1,1]
	local sd_`reg'_`yr' = sqrt(v[1,1])
	local t_`reg'_`yr' = `b_`reg'_`yr'' / `sd_`reg'_`yr''
	local p_`reg'_`yr' = 2 * ttail(e(df_r), abs(`t_`reg'_`yr''))
	local fe_`reg' = 1 // fixed effects
	local c1_`reg' = 0 // quarterly dummies
	local c2_`reg' = 1 // per pupil expenditures 
	local c3_`reg' = 1 // property taxes 
	local c4_`reg' = 1 // demographics 
	local c5_`reg' = 0 // parcel I controls 
	local c6_`reg' = 0 // parcel II controls  

	/*Regression B1*/
	local reg b1
	disp "Reg = `reg' and year = `yr'"
	xi: xtreg pricepersflandgross own_wrluri own_mean_pp_expend own_mean_ptax $own_demo ///
		$parcel1 q* if $if_own, fe robust cluster (border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`yr' = b[1,1]
	local sd_`reg'_`yr' = sqrt(v[1,1])
	local t_`reg'_`yr' = `b_`reg'_`yr'' / `sd_`reg'_`yr''
	local p_`reg'_`yr' = 2 * ttail(e(df_r), abs(`t_`reg'_`yr''))
	local fe_`reg' = 1 // fixed effects
	local c1_`reg' = 1 // quarterly dummies
	local c2_`reg' = 1 // per pupil expenditures 
	local c3_`reg' = 1 // property taxes 
	local c4_`reg' = 1 // demographics 
	local c5_`reg' = 1 // parcel I controls 
	local c6_`reg' = 0 // parcel II controls 

	/*Regression B2*/
	local reg b2
	disp "Reg = `reg' and year = `yr'"
	xi: xtreg pricepersflandgross own_wrluri own_mean_pp_expend own_mean_ptax $own_demo ///
		$parcel1 if $if_own, fe robust cluster (border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`yr' = b[1,1]
	local sd_`reg'_`yr' = sqrt(v[1,1])
	local t_`reg'_`yr' = `b_`reg'_`yr'' / `sd_`reg'_`yr''
	local p_`reg'_`yr' = 2 * ttail(e(df_r), abs(`t_`reg'_`yr''))
	local fe_`reg' = 1 // fixed effects
	local c1_`reg' = 0 // quarterly dummies
	local c2_`reg' = 1 // per pupil expenditures 
	local c3_`reg' = 1 // property taxes 
	local c4_`reg' = 1 // demographics 
	local c5_`reg' = 1 // parcel I controls 
	local c6_`reg' = 0 // parcel II controls 
	
	/*Regression C1*/
	local reg c1
	disp "Reg = `reg' and year = `yr'"
	xi: xtreg pricepersflandgross own_wrluri own_mean_pp_expend own_mean_ptax $own_demo ///
		$parcel1 $parcel2 q* if $if_own, fe robust cluster (border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`yr' = b[1,1]
	local sd_`reg'_`yr' = sqrt(v[1,1])
	local t_`reg'_`yr' = `b_`reg'_`yr'' / `sd_`reg'_`yr''
	local p_`reg'_`yr' = 2 * ttail(e(df_r), abs(`t_`reg'_`yr''))
	local fe_`reg' = 1 // fixed effects
	local c1_`reg' = 1 // quarterly dummies
	local c2_`reg' = 1 // per pupil expenditures 
	local c3_`reg' = 1 // property taxes 
	local c4_`reg' = 1 // demographics 
	local c5_`reg' = 1 // parcel I controls 
	local c6_`reg' = 1 // parcel II controls
	
	/*Regression C2*/
	local reg c2
	disp "Reg = `reg' and year = `yr'"
	xi: xtreg pricepersflandgross own_wrluri own_mean_pp_expend own_mean_ptax $own_demo ///
		$parcel1 $parcel2 if $if_own, fe robust cluster (border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`yr' = b[1,1]
	local sd_`reg'_`yr' = sqrt(v[1,1])
	local t_`reg'_`yr' = `b_`reg'_`yr'' / `sd_`reg'_`yr''
	local p_`reg'_`yr' = 2 * ttail(e(df_r), abs(`t_`reg'_`yr''))
	local fe_`reg' = 1 // fixed effects
	local c1_`reg' = 0 // quarterly dummies
	local c2_`reg' = 1 // per pupil expenditures 
	local c3_`reg' = 1 // property taxes 
	local c4_`reg' = 1 // demographics 
	local c5_`reg' = 1 // parcel I controls 
	local c6_`reg' = 1 // parcel II controls
	restore
}

**************************************************************************************************************
* BUILD REGRESSION TABLE
**************************************************************************************************************

/*Generate variables for table*/
clear
gen yr = ""
gen temp = ""
foreach x in a1 a2 b1 b2 c1 c2 {
	gen reg_`x' = . 
}

/*Set the number of observations*/
set obs 12

/*Fill in variable and control labels*/
local list1 `""[2000-2009]" "[2003-2009]""'
forvalues x = 1/1 {
	replace yr = "WRLURI 1km (dist < 0.1)" in `x' 
}
local i = 1
forvalues x = 2(2)4 {
	local name1 : word `i' of `list1'
	replace yr = "`name1'" in `x'
	local i = `i' + 1
}
#delimit ;
local list2 `""Border pair FE" "Quarter dummies" "Per pupil expenditures" "Property taxes per acre"
	"Demographics" "Parcel controls I" "Parcel controls II""';
#delimit cr
local i = 1 
forvalues x = 6/12 {
	local name2 : word `i' of `list2'
	replace yr = "`name2'" in `x' 
	local i = `i' + 1
}

/*Fill in temporary variable*/
local list1 `""00" "03""'
local list2 `""fe" "c1" "c2" "c3" "c4" "c5" "c6""'
local i = 1
forvalues x = 2(2)4 {
	local name1 : word `i' of `list1'
	replace temp = "`name1'" in `x'
	local i = `i' + 1
}
local i = 1
forvalues x = 6/12 {
	local name2 : word `i' of `list2'
	replace temp = "`name2'" in `x'
	local i = `i' + 1
}

/*Fill in the table*/
local N = _N 
foreach reg in a1 a2 b1 b2 c1 c2 {
	foreach yr in 00 03 {
		forvalues x = 1/`N' {
			if "`yr'" == temp[`x'] {
				local y = `x' + 1 
				capture replace reg_`reg' = `b_`reg'_`yr'' in `x' 
				capture replace reg_`reg' = `sd_`reg'_`yr'' in `y' 
			}
		}
	}
	foreach control in fe c1 c2 c3 c4 c5 c6 {
		forvalues x = 1/`N' {
			if "`control'" == temp[`x'] {
				capture replace reg_`reg' = ``control'_`reg'' in `x' 
			}
		}
	}
}

/*Add column labels and convert variables to strings*/
local list1 `""(1)" "(2)" "(3)" "(4)" "(5)" "(6)""'
local i = 1 
foreach x in a1 a2 b1 b2 c1 c2 {
	tostring reg_`x', replace force format(%10.2f)
	local name1 : word `i' of `list1'
	replace reg_`x' = "`name1'" in 1
	local i = `i' + 1
}

/*Add in significance stars*/
local N = _N
foreach reg in a1 a2 b1 b2 c1 c2 {
	foreach yr in 00 03 {
		forvalues x = 1/`N' {	
			if "`yr'" == temp[`x'] {
				local y = `x' + 1
				local sd = reg_`reg'[`y'] 
				capture local p = `p_`reg'_`yr''
				if `p' > 0.1 {
					capture replace reg_`reg' = "(" + "`sd'" + ")" in `y' 
				}
				if `p' <= 0.1 & `p' > 0.05 {
					local star "*"
					capture replace reg_`reg' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}
				if `p' <= 0.05 & `p' > 0.01 {
					local star "**"
					capture replace reg_`reg' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}	
				if `p' <= 0.01 { 
					local star "***"
					capture replace reg_`reg' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}		
			}
		}
	}
}

/*Replace controls = 1 with controls = Y*/
local N = _N
foreach reg in a1 a2 b1 b2 c1 c2 {
	forvalues x = 6/`N' {
		if reg_`reg'[`x'] == "1.00" {
			replace reg_`reg' = "Y" in `x' 
		}
		if reg_`reg'[`x'] == "0.00" {
			replace reg_`reg' = "" in `x' 
		}
	}
}

drop temp
export excel using table3_ownlot_robustness_timing.xls, replace

**************************************************************************************************************
* Table 4 - Own-lot Effect regressions, robustness to demographics
**************************************************************************************************************
use parcel_data, clear

/*Control variable lists*/
global parcel1 land landsq log_cbd_dist log_cbd_dist2 us990_tri us990_tri_5km us990_tri_10km
global parcel2 emp94 emp94_5km emp94_10km dev90 dev90_5km dev90_10km 
global own_demo own_black own_asian own_edu_hs own_edu_bs own_med_hh_inc 
global ex_demo d_int_black d_int_asian d_int_edu_hs d_int_edu_bs d_int_med_hh_inc 

/*Distance threshold*/
global dist = 0.1

/*Tag all parcels = 1 if they are attached to borders for which some parcel is less than $dist from a 
straight line border*/
sort border_code nbr_dist
by border_code : egen min_dist_straight = min(nbr_dist) if straight_new_dis_noc1km == 1
gen border_straight_temp = (min_dist_straight < $dist)
by border_code : egen border_straight = max(border_straight_temp) 
drop border_straight_temp min_dist_straight

/*Thresholds for bins*/
global bins "0.5 0.25 0.25"
global interior1 = real(word("$bins", 1))
global interior2 = real(word("$bins", 2))
global peripheral1 = real(word("$bins", 3))

/*Create indicator variables = 1 if parcel is in each interior bin & interact these with the regulation 
variable*/
gen int_flag = 1 if nbr_dist < $interior1 & nbr_dist > $interior2
replace int_flag = 0 if int_flag == . 
gen d_wrluri_int = d_wrluri * int_flag

/*Create squared and log demographic variables*/
gen own_log_med_hh_inc = log(own_med_hh_inc)
gen nbr_log_med_hh_inc = log(nbr_med_hh_inc)
foreach var in own_black own_asian own_edu_hs own_edu_bs own_med_hh_inc {
	gen `var'2 = `var' * `var' 
}

/*Construct change in demograhics variables interacted with interior parcel dummy to use as demographic 
controls*/
foreach cat in black asian edu_hs edu_bs med_hh_inc log_med_hh_inc {
	gen d_int_`cat' = (own_`cat' - nbr_`cat') * int_flag
}

/*Construct change in school/local finance variables interacted with interior parcel dummy*/
foreach var in pp_expend ptax {
	gen d_int_`var' = (own_mean_`var' - nbr_mean_`var') * int_flag
}

**************************************************************************************************************
* CONDITIONAL STATEMENTS AND GENERAL SAMPLE RESTRICTIONS
**************************************************************************************************************

/*Conditional statements*/
global if_own "(nbr_dist < $dist) & (border_straight == 1)"
global if_ex "((nbr_dist < $peripheral1) | (nbr_dist < $interior1 & nbr_dist > $interior2))"

/*General sample restrictions*/
drop if straight_new_dis_noc1km == 0 

xtset border_code

**************************************************************************************************************
* OWN-LOT EFFECT REGRESSIONS (2000-2009)
**************************************************************************************************************

/*Restrict date range*/
drop if own_wrluri == . 
drop if year_lt00 > 0 
drop q19832 - q19994

global control_a own_mean_pp_expend own_mean_ptax $own_demo 
global control_b own_mean_pp_expend own_mean_ptax $own_demo $parcel1
global control_c own_mean_pp_expend own_mean_ptax $own_demo $parcel1 $parcel2

global c_a 1 1 1 1 1 0 0
global c_b 1 1 1 1 1 1 0
global c_c 1 1 1 1 1 1 1  

foreach x in a b c {

	/*Controls*/
	local fe_`x' : word 1 of ${c_`x'} 
	local c1_`x' : word 2 of ${c_`x'}
	local c2_`x' : word 3 of ${c_`x'}
	local c3_`x' : word 4 of ${c_`x'}
	local c4_`x' : word 5 of ${c_`x'}
	local c5_`x' : word 6 of ${c_`x'}
	local c6_`x' : word 7 of ${c_`x'}

	/*Regression 1*/
	global control_a own_mean_pt_ratio own_mean_ptax $own_demo 
	global control_b own_mean_pt_ratio own_mean_ptax $own_demo $parcel1
	global control_c own_mean_pt_ratio own_mean_ptax $own_demo $parcel1 $parcel2
	local reg 1
	disp "Reg = `reg' and control group = `x'"
	xi: xtreg pricepersflandgross own_wrluri ${control_`x'} q* if $if_own, fe robust cluster (border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`x'= b[1,1]
	local sd_`reg'_`x'= sqrt(v[1,1])
	local t_`reg'_`x'= `b_`reg'_`x'' / `sd_`reg'_`x''
	local p_`reg'_`x'= 2 * ttail(e(df_r), abs(`t_`reg'_`x''))
	global control_a own_mean_pp_expend own_mean_ptax $own_demo 
	global control_b own_mean_pp_expend own_mean_ptax $own_demo $parcel1
	global control_c own_mean_pp_expend own_mean_ptax $own_demo $parcel1 $parcel2

	/*Regression 2*/
	local reg 2
	disp "Reg = `reg' and control group = `x'"
	xi: xtreg pricepersflandgross own_wrluri ${control_`x'} own_mean_pt_ratio q* if $if_own, ///
		fe robust cluster (border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`x'= b[1,1]
	local sd_`reg'_`x'= sqrt(v[1,1])
	local t_`reg'_`x'= `b_`reg'_`x'' / `sd_`reg'_`x''
	local p_`reg'_`x'= 2 * ttail(e(df_r), abs(`t_`reg'_`x''))

	/*Regression 3*/
	global own_demo own_black own_asian own_edu_hs own_edu_bs own_log_med_hh_inc 
	global control_a own_mean_pp_expend own_mean_ptax $own_demo 
	global control_b own_mean_pp_expend own_mean_ptax $own_demo $parcel1
	global control_c own_mean_pp_expend own_mean_ptax $own_demo $parcel1 $parcel2
	local reg 3
	disp "Reg = `reg' and control group = `x'"
	xi: xtreg pricepersflandgross own_wrluri ${control_`x'} q* if $if_own, fe robust cluster (border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`x'= b[1,1]
	local sd_`reg'_`x'= sqrt(v[1,1])
	local t_`reg'_`x'= `b_`reg'_`x'' / `sd_`reg'_`x''
	local p_`reg'_`x'= 2 * ttail(e(df_r), abs(`t_`reg'_`x''))
	global own_demo own_black own_asian own_edu_hs own_edu_bs own_med_hh_inc 
	global control_a own_mean_pp_expend own_mean_ptax $own_demo 
	global control_b own_mean_pp_expend own_mean_ptax $own_demo $parcel1
	global control_c own_mean_pp_expend own_mean_ptax $own_demo $parcel1 $parcel2

	/*Regression 4*/
	local reg 4
	disp "Reg = `reg' and control group = `x'"
	xi: xtreg pricepersflandgross own_wrluri ${control_`x'} own_med_hh_inc2 q* if $if_own, ///
		fe robust cluster (border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`x'= b[1,1]
	local sd_`reg'_`x'= sqrt(v[1,1])
	local t_`reg'_`x'= `b_`reg'_`x'' / `sd_`reg'_`x''
	local p_`reg'_`x'= 2 * ttail(e(df_r), abs(`t_`reg'_`x''))

	/*Regression 5*/
	local reg 5
	disp "Reg = `reg' and control group = `x'"
	xi: xtreg pricepersflandgross own_wrluri ${control_`x'} own_black2 own_asian2 ///
		own_edu_hs2 own_edu_bs2 own_med_hh_inc2 q* if $if_own, fe robust cluster (border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`x'= b[1,1]
	local sd_`reg'_`x'= sqrt(v[1,1])
	local t_`reg'_`x'= `b_`reg'_`x'' / `sd_`reg'_`x''
	local p_`reg'_`x'= 2 * ttail(e(df_r), abs(`t_`reg'_`x''))
}

**************************************************************************************************************
* BUILD REGRESSION TABLE
**************************************************************************************************************

/*Generate variables for table*/
clear
gen spec = ""
gen temp = ""
foreach x in a b c {
	gen reg_`x' = . 
}

/*Set the number of observations*/
set obs 19

/*Fill in variable and control labels*/
forvalues x = 1/1 {
	replace spec = "WRLURI 1km (dist < 0.1)" in `x' 
}
#delimit ; 
local list1 `""Sub P/T ratio for PP-expenditures" "Add P/T ratio" "Sub log income for income" 
	"Add income^2" "Add demographic quadratic terms""';
local list2 `""Border pair FE" "Quarter dummies" "Per pupil expenditures" "Property taxes per acre" 
	"Demographics" "Parcel controls I" "Parcel controls II""';
#delimit cr
local i = 1
forvalues x = 2(2)10 {
	local name1 : word `i' of `list1'
	replace spec = "`name1'" in `x'
	local i = `i' + 1
}
replace spec = "Initial controls" in 12
local i = 1 
forvalues x = 13/19 {
	local name2 : word `i' of `list2'
	replace spec = "`name2'" in `x' 
	local i = `i' + 1
}

/*Fill in temporary variable*/
local i = 1
forvalues x = 2(2)10 {
	replace temp = "`i'" in `x'
	local i = `i' + 1
}
local i = 1 
local list1 `""fe" "c1" "c2" "c3" "c4" "c5" "c6""'
forvalues x = 13/19 {
	local name1 : word `i' of `list1'
	replace temp = "`name1'" in `x' 
	local i = `i' + 1
}

/*Fill in the table*/
local N = _N
foreach spec in a b c {
	forvalues reg = 1/5 {
		forvalues x = 1/`N' {
			if "`reg'" == temp[`x'] {
				local y = `x' + 1 
				capture replace reg_`spec' = `b_`reg'_`spec'' in `x' 
				capture replace reg_`spec' = `sd_`reg'_`spec'' in `y'
			}
		}
	}
	foreach control in fe c1 c2 c3 c4 c5 c6 {
		forvalues x = 1/`N' {
			if "`control'" == temp[`x'] {
				capture replace reg_`spec' = ``control'_`spec'' in `x' 
			}
		}
	}
}

/*Add column labels and convert variables to strings*/
local list1 `""(1)" "(2)" "(3)""'
local i = 1 
foreach x in a b c {
	tostring reg_`x', replace force format(%10.2f)
	local name1 : word `i' of `list1'
	replace reg_`x' = "`name1'" in 1 
	local i = `i' + 1
}

/*Add in significance stars*/
local N = _N
forvalues reg = 1/5 {
	foreach spec in a b c {
		forvalues x = 1/`N' {
			if "`reg'" == temp[`x'] {
				local y = `x' + 1
				local sd = reg_`spec'[`y'] 
				capture local p = `p_`reg'_`spec''
				if `p' > 0.1 {
					capture replace reg_`spec' = "(" + "`sd'" + ")" in `y' 
				}
				if `p' <= 0.1 & `p' > 0.05 {
					local star "*"
					capture replace reg_`spec' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}
				if `p' <= 0.05 & `p' > 0.01 {
					local star "**"
					capture replace reg_`spec' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}	
				if `p' <= 0.01 { 
					local star "***"
					capture replace reg_`spec' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}		
			}
		}
	}
}

/*Replace controls = 1 with controls = Y*/
local N = _N
foreach reg in a b c {
	forvalues x = 13/`N' {
		if reg_`reg'[`x'] == "1.00" {
			replace reg_`reg' = "Y" in `x' 
		}
		if reg_`reg'[`x'] == "0.00" {
			replace reg_`reg' = "" in `x' 
		}
	}
	replace reg_`reg' = "" if reg_`reg' == "." 
}


/*Save file*/
drop temp
export excel using table4_ownlot_robustness_demos.xls, replace

**************************************************************************************************************
* Table 5 - Own-lot Effect regressions, robustness to functional form
**************************************************************************************************************

use parcel_data, clear

/*Control variable lists*/
global parcel1 land landsq log_cbd_dist log_cbd_dist2 us990_tri us990_tri_5km us990_tri_10km
global parcel2 emp94 emp94_5km emp94_10km dev90 dev90_5km dev90_10km 
global own_demo own_black own_asian own_edu_hs own_edu_bs own_med_hh_inc 
global ex_demo d_int_black d_int_asian d_int_edu_hs d_int_edu_bs d_int_med_hh_inc 

/*Distance threshold*/
global dist = 0.1

/*Tag all parcels = 1 if they are attached to borders for which some parcel is less than $dist from a 
straight line border*/
sort border_code nbr_dist
by border_code : egen min_dist_straight = min(nbr_dist) if straight_new_dis_noc1km == 1
gen border_straight_temp = (min_dist_straight < $dist)
by border_code : egen border_straight = max(border_straight_temp) 
drop border_straight_temp min_dist_straight

/*Thresholds for bins*/
global bins "0.5 0.25 0.25"
global interior1 = real(word("$bins", 1))
global interior2 = real(word("$bins", 2))
global peripheral1 = real(word("$bins", 3))

/*Create indicator variables = 1 if parcel is in each interior bin & interact these with the regulation 
variable*/
gen int_flag = 1 if nbr_dist < $interior1 & nbr_dist > $interior2
replace int_flag = 0 if int_flag == . 
gen d_wrluri_int = d_wrluri * int_flag

/*Create squared and log variables*/
gen own_log_med_hh_inc = log(own_med_hh_inc)
gen nbr_log_med_hh_inc = log(nbr_med_hh_inc)
foreach var in own_black own_asian own_edu_hs own_edu_bs own_med_hh_inc own_wrluri {
	gen `var'2 = `var' * `var' 
}

/*Interact regulation variables with residential dummy*/
foreach var in own_wrluri own_llla own_dri own_osi {
	gen `var'_res = `var' * residentialland
}

/*Construct change in demograhics variables interacted with interior parcel dummy to use as demographic 
controls*/
foreach cat in black asian edu_hs edu_bs med_hh_inc log_med_hh_inc {
	gen d_int_`cat' = (own_`cat' - nbr_`cat') * int_flag
}

/*Construct change in school/local finance variables interacted with interior parcel dummy*/
foreach var in pp_expend ptax {
	gen d_int_`var' = (own_mean_`var' - nbr_mean_`var') * int_flag
}

**************************************************************************************************************
* CONDITIONAL STATEMENTS AND GENERAL SAMPLE RESTRICTIONS
**************************************************************************************************************

/*Conditional statements*/
global if_own "(nbr_dist < $dist) & (border_straight == 1)"
global if_ex "((nbr_dist < $peripheral1) | (nbr_dist < $interior1 & nbr_dist > $interior2))"

/*General sample restrictions*/
drop if straight_new_dis_noc1km == 0 

xtset border_code

**************************************************************************************************************
* OWN-LOT EFFECT REGRESSIONS (2000-2009)
**************************************************************************************************************

/*Restrict date range*/
drop if own_wrluri == . 
drop if year_lt00 > 0 
drop q19832 - q19994

global control_a own_mean_pp_expend own_mean_ptax $own_demo
global control_b own_mean_pp_expend own_mean_ptax $own_demo $parcel1
global control_c own_mean_pp_expend own_mean_ptax $own_demo $parcel1 $parcel2

local clist_a 1 1 1 1 1 0 0 
local clist_b 1 1 1 1 1 1 0 
local clist_c 1 1 1 1 1 1 1

foreach x in a b c {

	/*Control lists*/
	local fe_`x' : word 1 of `clist_`x''
	local c1_`x' : word 2 of `clist_`x''
	local c2_`x' : word 3 of `clist_`x''
	local c3_`x' : word 4 of `clist_`x''
	local c4_`x' : word 5 of `clist_`x''
	local c5_`x' : word 6 of `clist_`x''
	local c6_`x' : word 7 of `clist_`x''

	/*Regression 1*/
	local reg 1
	disp "Reg = `reg' and control group = `x'"
	xi: xtreg pricepersflandgross own_wrluri own_wrluri2 ${control_`x'} q* if $if_own, ///
		fe robust cluster (border_code)
	matrix b = e(b)
	matrix v = e(V)
	forvalues y = 1/2 {
		local b`y'_`reg'_`x'= b[1,`y']
		local sd`y'_`reg'_`x'= sqrt(v[`y',`y'])
		local t`y'_`reg'_`x'= `b`y'_`reg'_`x'' / `sd`y'_`reg'_`x''
		local p`y'_`reg'_`x'= 2 * ttail(e(df_r), abs(`t`y'_`reg'_`x''))
	}
}

**************************************************************************************************************
* BUILD REGRESSION TABLE
**************************************************************************************************************

/*Generate variables for table*/
clear
gen spec = ""
gen coef = ""
gen temp1 = ""
gen temp2 = ""
foreach x in a b c {
	gen reg_`x' = . 
}

/*Set the number of observations*/
set obs 12

/*Fill in variable and control labels*/
forvalues x = 1/1 {
	replace spec = "WRLURI 1km (dist < 0.1)" in `x' 
}
#delimit ;
local list1 `""Add WRLURI^2""';
local list2 `""Border pair FE" "Quarter dummies" "Per pupil expenditures" "Property taxes per acre"
	"Demographics" "Parcel controls I" "Parcel controls II""';
#delimit cr
local i = 1
foreach x in 2 {
	local name1 : word `i' of `list1'
	replace spec = "`name1'" in `x'
	local i = `i' + 1
}
local i = 1 
forvalues x = 6/12 {
	local name2 : word `i' of `list2'
	replace spec = "`name2'" in `x' 
	local i = `i' + 1
}

/*Fill in temporary variables*/
local i = 1
local list1 1 1 
local list2 1 2 
local list3 `""WRLURI" "WRLURI^2""'
forvalues x = 2(2)4 {
	local name1 : word `i' of `list1'
	local name2 : word `i' of `list2' 
	local name3 : word `i' of `list3' 
	replace temp1 = "`name1'" in `x'
	replace temp2 = "`name2'" in `x' 
	replace coef = "`name3'" in `x' 
	local i = `i' + 1
}
local list4 `""fe" "c1" "c2" "c3" "c4" "c5" "c6""'
local i = 1 
forvalues x = 6/12 {
	local name4 : word `i' of `list4' 
	replace temp1 = "`name4'" in `x' 
	local i = `i' + 1 
}

/*Fill in the table*/
local N = _N
forvalues reg = 1/1 {
	foreach spec in a b c {
		foreach coef in 1 2 {
			forvalues x = 1/`N' {
				if "`reg'" == temp1[`x'] & "`coef'" == temp2[`x'] {
					local y = `x' + 1 
					capture replace reg_`spec' = `b`coef'_`reg'_`spec'' in `x' 
					capture replace reg_`spec' = `sd`coef'_`reg'_`spec'' in `y'
				}
			}
		}
		foreach control in fe c1 c2 c3 c4 c5 c6 {
			forvalues x = 1/`N' {
				if "`control'" == temp1[`x'] {
					capture replace reg_`spec' = ``control'_`spec'' in `x' 
				}
			}
		}
	}
}

/*Add column labels and convert variables to strings*/
local list1 `""(1)" "(2)" "(3)""'
local i = 1 
foreach x in a b c {
	tostring reg_`x', replace force format(%10.2f)
	local name1 : word `i' of `list1'
	replace reg_`x' = "`name1'" in 1 
	local i = `i' + 1
}
forvalues x = 1/1 {
	replace coef = "coef" in `x' 
}

/*Add in significance stars*/
local N = _N
forvalues reg = 1/1 {
	foreach spec in a b c {
		foreach coef in 1 2 {
			forvalues x = 1/`N' {
				if "`reg'" == temp1[`x'] & "`coef'" == temp2[`x'] {
					local y = `x' + 1
					local sd = reg_`spec'[`y'] 
					capture local p = `p`coef'_`reg'_`spec''
					if `p' > 0.1 {
						capture replace reg_`spec' = "(" + "`sd'" + ")" in `y' 
					}
					if `p' <= 0.1 & `p' > 0.05 {
						local star "*"
						capture replace reg_`spec' = "(" + "`sd'" + ")" + "`star'" in `y' 
					}
					if `p' <= 0.05 & `p' > 0.01 {
						local star "**"
						capture replace reg_`spec' = "(" + "`sd'" + ")" + "`star'" in `y' 
					}	
					if `p' <= 0.01 { 
					local star "***"
						capture replace reg_`spec' = "(" + "`sd'" + ")" + "`star'" in `y' 
					}
				}		
			}
		}
	}
}

/*Replace controls = 1 with controls = Y*/
local N = _N
foreach reg in a b c {
	forvalues x = 6/`N' {
		if reg_`reg'[`x'] == "1.00" {
			replace reg_`reg' = "Y" in `x' 
		}
		if reg_`reg'[`x'] == "0.00" {
			replace reg_`reg' = "" in `x' 
		}
	}
}

/*Save file*/
drop temp*
export excel using table5_ownlot_robustness_form.xls, replace

**************************************************************************************************************
* Table 6 - External Effect regressions
**************************************************************************************************************

use parcel_data, clear

**************************************************************************************************************
* LOOP OVER REGULATION VARIABLES, STRAIGHT BORDER VARIABLES, AND SAMPLE RANGES
**************************************************************************************************************

foreach regvar in d_wrluri d_llla d_dri d_osi {
	foreach straight in 500m 1km {
		foreach yr in 00 {

			********************************************************************************************
			* SET BINS AND CREATE LISTS OF CONTROL VARIABLES
			********************************************************************************************

			/*List of control variables to be used in regressions*/
			global controls3 land landsq log_cbd_dist log_cbd_dist2 us990_tri us990_tri_5km us990_tri_10km
			global controls4 emp94 emp94_5km emp94_10km dev90 dev90_5km dev90_10km 
			forvalues x = 1/3 {
				global controls1`x' d_int_pp_expend`x' d_int_ptax`x'
				global controls2`x' d_int_black`x' d_int_asian`x' d_int_edu_hs`x' d_int_edu_bs`x' ///
					d_int_med_hh_inc`x' // interactions between demographics and interior dummies
				global controls5`x' int_flag`x' // interior bin indicators
			}

			/*Set thresholds for peripheral and interior bins*/
			global bins1 "1 0.5 0.1"
			global bins2 "0.5 0.25 0.25"
			global bins3 "0.5 0.25 0.1"

			/*Parse input of bins*/
			forvalues x = 1/3 {
				global interior1_`x' = real(word("${bins`x'}", 1))
				global interior2_`x' = real(word("${bins`x'}", 2))
				global peripheral1_`x' = real(word("${bins`x'}", 3))
			}

			/*Make conditional statments for each set of bins*/
			forvalues x = 1/3 {
				#delimit ; 
				global if_`x' "((nbr_dist < ${peripheral1_`x'}) | (nbr_dist < ${interior1_`x'} &
					nbr_dist > ${interior2_`x'}))";
				#delimit cr
			}

			********************************************************************************************
			* LOAD DATA AND IMPOSE SAMPLE RESTRICTIONS
			********************************************************************************************

			use parcel_data, clear

			/*Drop observations that are missing the regulation variable of interest*/
			drop if `regvar' == . 

			/*Restrict sample to straight borders*/
			drop if straight_new_dis_noc`straight' == 0 

			/*Restrict dates in sample*/
			drop if year_lt`yr' > 0

			/*Drop extraneous quarterly dummies*/
			if `yr' == 00 {
				drop q19832 - q19994
			}
			if `yr' == 90 {
				drop q19832 - q19894
			}

			/*Create indicator variables = 1 if parcel is in each interior bin & interact these with the 
			regulation variable of interest*/
			forvalues x = 1/3 {
				gen int_flag`x' = 1 if nbr_dist < ${interior1_`x'} & nbr_dist > ${interior2_`x'}
				replace int_flag`x' = 0 if int_flag`x' == . 
				gen `regvar'_int`x' = `regvar' * int_flag`x' 
			}
		
			/*Construct change in demograhics variables interacted with interior parcel dummy to use as
			demographic controls*/
			forvalues x = 1/3 {
				foreach cat in black asian edu_hs edu_bs med_hh_inc {
					gen d_int_`cat'`x' = (own_`cat' - nbr_`cat') * int_flag`x'
				}
			}

			/*Construct change in school/local finance variables interacted with interior parcel dummy*/
			forvalues x = 1/3 {
				foreach var in pp_expend ptax {
					gen d_int_`var'`x' = (own_mean_`var' - nbr_mean_`var') * int_flag`x' 
				}
			}

			/*Set up municipality border code fixed effects*/
			xtset muni_border_code

			********************************************************************************************
			* REGRESSIONS
			********************************************************************************************

			/*Regression 1*/
			local reg = 1
			forvalues x = 1/3 {
				disp "Regression `reg' for year `yr' and sample `straight'"
				disp "Bin `x'"
				xi: xtreg pricepersflandgross `regvar'_int`x' q* if ${if_`x'}, fe robust cluster ///
					(muni_border_code)
				matrix b = e(b)
				matrix v = e(V)
				local b_`reg'_`yr'_`regvar'_`straight'_`x' = b[1,1]
				local sd_`reg'_`yr'_`regvar'_`straight'_`x' = sqrt(v[1,1])
				local obs_`reg'_`yr'_`regvar'_`straight'_`x' `e(N)'
				local g_`reg'_`yr'_`regvar'_`straight'_`x' `e(N_g)'
				local t_`reg'_`yr'_`regvar'_`straight'_`x' = ///
					`b_`reg'_`yr'_`regvar'_`straight'_`x'' / `sd_`reg'_`yr'_`regvar'_`straight'_`x''
				local p_`reg'_`yr'_`regvar'_`straight'_`x' = 2 * ttail(e(df_r), ///
					abs(`t_`reg'_`yr'_`regvar'_`straight'_`x''))
			}
			local fe_`reg'_`yr'_`regvar'_`straight' = 1 // fixed effects
			local c1_`reg'_`yr'_`regvar'_`straight' = 1 // quarterly dummies
			local c2_`reg'_`yr'_`regvar'_`straight' = 0 // per pupil expenditures
			local c3_`reg'_`yr'_`regvar'_`straight' = 0 // property taxes
			local c4_`reg'_`yr'_`regvar'_`straight' = 0 // demographics 
			local c5_`reg'_`yr'_`regvar'_`straight' = 0 // parcel I controls
			local c6_`reg'_`yr'_`regvar'_`straight' = 0 // parcel II controls
			local c7_`reg'_`yr'_`regvar'_`straight' = 0 // interior dummy 
			
			/*Regression 2*/
			local reg = 2
			forvalues x = 1/3 {
				disp "Regression `reg' for year `yr' and sample `straight'"
				disp "Bin `x'"
				xi: xtreg pricepersflandgross `regvar'_int`x' ${controls1`x'} q* if ${if_`x'}, ///
					fe robust cluster (muni_border_code)
				matrix b = e(b)
				matrix v = e(V)
				local b_`reg'_`yr'_`regvar'_`straight'_`x' = b[1,1]
				local sd_`reg'_`yr'_`regvar'_`straight'_`x' = sqrt(v[1,1])
				local obs_`reg'_`yr'_`regvar'_`straight'_`x' `e(N)'
				local g_`reg'_`yr'_`regvar'_`straight'_`x' `e(N_g)'
				local t_`reg'_`yr'_`regvar'_`straight'_`x' = ///
					`b_`reg'_`yr'_`regvar'_`straight'_`x'' / `sd_`reg'_`yr'_`regvar'_`straight'_`x''
				local p_`reg'_`yr'_`regvar'_`straight'_`x' = 2 * ttail(e(df_r), ///
					abs(`t_`reg'_`yr'_`regvar'_`straight'_`x''))
			}
			local fe_`reg'_`yr'_`regvar'_`straight' = 1 // fixed effects
			local c1_`reg'_`yr'_`regvar'_`straight' = 1 // quarterly dummies
			local c2_`reg'_`yr'_`regvar'_`straight' = 1 // per pupil expenditures
			local c3_`reg'_`yr'_`regvar'_`straight' = 1 // property taxes
			local c4_`reg'_`yr'_`regvar'_`straight' = 0 // demographics 
			local c5_`reg'_`yr'_`regvar'_`straight' = 0 // parcel I controls
			local c6_`reg'_`yr'_`regvar'_`straight' = 0 // parcel II controls
			local c7_`reg'_`yr'_`regvar'_`straight' = 0 // interior dummy 
			
			/*Regression 3*/
			local reg = 3
			forvalues x = 1/3 {
				disp "Regression `reg' for year `yr' and sample `straight'"
				disp "Bin `x'"
				xi: xtreg pricepersflandgross `regvar'_int`x' ${controls2`x'} $controls3 q* ///
					if ${if_`x'}, fe robust cluster (muni_border_code)
				matrix b = e(b)
				matrix v = e(V)
				local b_`reg'_`yr'_`regvar'_`straight'_`x' = b[1,1]
				local sd_`reg'_`yr'_`regvar'_`straight'_`x' = sqrt(v[1,1])
				local obs_`reg'_`yr'_`regvar'_`straight'_`x' `e(N)'
				local g_`reg'_`yr'_`regvar'_`straight'_`x' `e(N_g)'
				local t_`reg'_`yr'_`regvar'_`straight'_`x' = ///
					`b_`reg'_`yr'_`regvar'_`straight'_`x'' / `sd_`reg'_`yr'_`regvar'_`straight'_`x''
				local p_`reg'_`yr'_`regvar'_`straight'_`x' = 2 * ttail(e(df_r), ///
					abs(`t_`reg'_`yr'_`regvar'_`straight'_`x''))
			}
			local fe_`reg'_`yr'_`regvar'_`straight' = 1 // fixed effects
			local c1_`reg'_`yr'_`regvar'_`straight' = 1 // quarterly dummies
			local c2_`reg'_`yr'_`regvar'_`straight' = 0 // per pupil expenditures
			local c3_`reg'_`yr'_`regvar'_`straight' = 0 // property taxes
			local c4_`reg'_`yr'_`regvar'_`straight' = 1 // demographics 
			local c5_`reg'_`yr'_`regvar'_`straight' = 1 // parcel I controls
			local c6_`reg'_`yr'_`regvar'_`straight' = 0 // parcel II controls
			local c7_`reg'_`yr'_`regvar'_`straight' = 0 // interior dummy
			
			/*Regression 4*/
			local reg = 4
			forvalues x = 1/3 {
				disp "Regression `reg' for year `yr' and sample `straight'"
				disp "Bin `x'"
				xi: xtreg pricepersflandgross `regvar'_int`x' ${controls2`x'} $controls3 ///
					$controls4 ${controls5`x'} q* if ${if_`x'}, fe robust cluster (muni_border_code)
				matrix b = e(b)
				matrix v = e(V)
				local b_`reg'_`yr'_`regvar'_`straight'_`x' = b[1,1]
				local sd_`reg'_`yr'_`regvar'_`straight'_`x' = sqrt(v[1,1])
				local obs_`reg'_`yr'_`regvar'_`straight'_`x' `e(N)'
				local g_`reg'_`yr'_`regvar'_`straight'_`x' `e(N_g)'
				local t_`reg'_`yr'_`regvar'_`straight'_`x' = ///
					`b_`reg'_`yr'_`regvar'_`straight'_`x'' / `sd_`reg'_`yr'_`regvar'_`straight'_`x''
				local p_`reg'_`yr'_`regvar'_`straight'_`x' = 2 * ttail(e(df_r), ///
					abs(`t_`reg'_`yr'_`regvar'_`straight'_`x''))
			}
			local fe_`reg'_`yr'_`regvar'_`straight' = 1 // fixed effects
			local c1_`reg'_`yr'_`regvar'_`straight' = 1 // quarterly dummies
			local c2_`reg'_`yr'_`regvar'_`straight' = 0 // per pupil expenditures
			local c3_`reg'_`yr'_`regvar'_`straight' = 0 // property taxes
			local c4_`reg'_`yr'_`regvar'_`straight' = 1 // demographics 
			local c5_`reg'_`yr'_`regvar'_`straight' = 1 // parcel I controls
			local c6_`reg'_`yr'_`regvar'_`straight' = 1 // parcel II controls
			local c7_`reg'_`yr'_`regvar'_`straight' = 1 // interior dummy
			
			/*Regression 5*/
			local reg = 5
			forvalues x = 1/3 {
				disp "Regression `reg' for year `yr' and sample `straight'"
				disp "Bin `x'"
				xi: xtreg pricepersflandgross `regvar'_int`x' ${controls1`x'} ${controls2`x'} ///
					$controls4 q* if ${if_`x'}, fe robust cluster (muni_border_code)
				matrix b = e(b)
				matrix v = e(V)
				local b_`reg'_`yr'_`regvar'_`straight'_`x' = b[1,1]
				local sd_`reg'_`yr'_`regvar'_`straight'_`x' = sqrt(v[1,1])
				local obs_`reg'_`yr'_`regvar'_`straight'_`x' `e(N)'
				local g_`reg'_`yr'_`regvar'_`straight'_`x' `e(N_g)'
				local t_`reg'_`yr'_`regvar'_`straight'_`x' = ///
					`b_`reg'_`yr'_`regvar'_`straight'_`x'' / `sd_`reg'_`yr'_`regvar'_`straight'_`x''
				local p_`reg'_`yr'_`regvar'_`straight'_`x' = 2 * ttail(e(df_r), ///
					abs(`t_`reg'_`yr'_`regvar'_`straight'_`x''))
			}
			local fe_`reg'_`yr'_`regvar'_`straight' = 1 // fixed effects
			local c1_`reg'_`yr'_`regvar'_`straight' = 1 // quarterly dummies
			local c2_`reg'_`yr'_`regvar'_`straight' = 1 // per pupil expenditures
			local c3_`reg'_`yr'_`regvar'_`straight' = 1 // property taxes
			local c4_`reg'_`yr'_`regvar'_`straight' = 1 // demographics 
			local c5_`reg'_`yr'_`regvar'_`straight' = 0 // parcel I controls
			local c6_`reg'_`yr'_`regvar'_`straight' = 1 // parcel II controls
			local c7_`reg'_`yr'_`regvar'_`straight' = 0 // interior dummy
			
			/*Regression 6*/
			local reg = 6
			forvalues x = 1/3 {
				disp "Regression `reg' for year `yr' and sample `straight'"
				disp "Bin `x'"
				xi: xtreg pricepersflandgross `regvar'_int`x' ${controls1`x'} ${controls2`x'} ///
					${controls5`x'} q* if ${if_`x'}, fe robust cluster (muni_border_code)
				matrix b = e(b)
				matrix v = e(V)
				local b_`reg'_`yr'_`regvar'_`straight'_`x' = b[1,1]
				local sd_`reg'_`yr'_`regvar'_`straight'_`x' = sqrt(v[1,1])
				local obs_`reg'_`yr'_`regvar'_`straight'_`x' `e(N)'
				local g_`reg'_`yr'_`regvar'_`straight'_`x' `e(N_g)'
				local t_`reg'_`yr'_`regvar'_`straight'_`x' = ///
					`b_`reg'_`yr'_`regvar'_`straight'_`x'' / `sd_`reg'_`yr'_`regvar'_`straight'_`x''
				local p_`reg'_`yr'_`regvar'_`straight'_`x' = 2 * ttail(e(df_r), ///
					abs(`t_`reg'_`yr'_`regvar'_`straight'_`x''))
			}
			local fe_`reg'_`yr'_`regvar'_`straight' = 1 // fixed effects
			local c1_`reg'_`yr'_`regvar'_`straight' = 1 // quarterly dummies
			local c2_`reg'_`yr'_`regvar'_`straight' = 1 // per pupil expenditures
			local c3_`reg'_`yr'_`regvar'_`straight' = 1 // property taxes
			local c4_`reg'_`yr'_`regvar'_`straight' = 1 // demographics 
			local c5_`reg'_`yr'_`regvar'_`straight' = 0 // parcel I controls
			local c6_`reg'_`yr'_`regvar'_`straight' = 0 // parcel II controls
			local c7_`reg'_`yr'_`regvar'_`straight' = 1 // interior dummy
			
			/*Regression 7*/
			local reg = 7
			forvalues x = 1/3 {
				disp "Regression `reg' for year `yr' and sample `straight'"
				disp "Bin `x'"
				xi: xtreg pricepersflandgross `regvar'_int`x' ${controls1`x'} ${controls2`x'} ///
					$controls3 $controls4 q* if ${if_`x'}, fe robust cluster (muni_border_code)
				matrix b = e(b)
				matrix v = e(V)
				local b_`reg'_`yr'_`regvar'_`straight'_`x' = b[1,1]
				local sd_`reg'_`yr'_`regvar'_`straight'_`x' = sqrt(v[1,1])
				local obs_`reg'_`yr'_`regvar'_`straight'_`x' `e(N)'
				local g_`reg'_`yr'_`regvar'_`straight'_`x' `e(N_g)'
				local t_`reg'_`yr'_`regvar'_`straight'_`x' = ///
					`b_`reg'_`yr'_`regvar'_`straight'_`x'' / `sd_`reg'_`yr'_`regvar'_`straight'_`x''
				local p_`reg'_`yr'_`regvar'_`straight'_`x' = 2 * ttail(e(df_r), ///
					abs(`t_`reg'_`yr'_`regvar'_`straight'_`x''))
			}
			local fe_`reg'_`yr'_`regvar'_`straight' = 1 // fixed effects
			local c1_`reg'_`yr'_`regvar'_`straight' = 1 // quarterly dummies
			local c2_`reg'_`yr'_`regvar'_`straight' = 1 // per pupil expenditures
			local c3_`reg'_`yr'_`regvar'_`straight' = 1 // property taxes
			local c4_`reg'_`yr'_`regvar'_`straight' = 1 // demographics 
			local c5_`reg'_`yr'_`regvar'_`straight' = 1 // parcel I controls
			local c6_`reg'_`yr'_`regvar'_`straight' = 1 // parcel II controls
			local c7_`reg'_`yr'_`regvar'_`straight' = 0 // interior dummy
			
			/*Regression 8*/
			local reg = 8
			forvalues x = 1/3 {
				disp "Regression `reg' for year `yr' and sample `straight'"
				disp "Bin `x'"
				xi: xtreg pricepersflandgross `regvar'_int`x' ${controls1`x'} ${controls2`x'} ///
					$controls3 $controls4 ${controls5`x'} q* if ${if_`x'}, fe robust cluster ///
					(muni_border_code)
				matrix b = e(b)
				matrix v = e(V)
				local b_`reg'_`yr'_`regvar'_`straight'_`x' = b[1,1]
				local sd_`reg'_`yr'_`regvar'_`straight'_`x' = sqrt(v[1,1])
				local obs_`reg'_`yr'_`regvar'_`straight'_`x' `e(N)'
				local g_`reg'_`yr'_`regvar'_`straight'_`x' `e(N_g)'
				local t_`reg'_`yr'_`regvar'_`straight'_`x' = ///
					`b_`reg'_`yr'_`regvar'_`straight'_`x'' / `sd_`reg'_`yr'_`regvar'_`straight'_`x''
				local p_`reg'_`yr'_`regvar'_`straight'_`x' = 2 * ttail(e(df_r), ///
					abs(`t_`reg'_`yr'_`regvar'_`straight'_`x''))
			}
			local fe_`reg'_`yr'_`regvar'_`straight' = 1 // fixed effects
			local c1_`reg'_`yr'_`regvar'_`straight' = 1 // quarterly dummies
			local c2_`reg'_`yr'_`regvar'_`straight' = 1 // per pupil expenditures
			local c3_`reg'_`yr'_`regvar'_`straight' = 1 // property taxes
			local c4_`reg'_`yr'_`regvar'_`straight' = 1 // demographics 
			local c5_`reg'_`yr'_`regvar'_`straight' = 1 // parcel I controls
			local c6_`reg'_`yr'_`regvar'_`straight' = 1 // parcel II controls
			local c7_`reg'_`yr'_`regvar'_`straight' = 1 // interior dummy
		}
	}
}

**************************************************************************************************************
* BUILD OUTPUT TABLE
**************************************************************************************************************

/*Generate variables for table*/
clear
gen bins = ""
gen temp1 = ""
gen temp2 = ""
gen temp3 = ""
foreach x in 1_00 2_00 3_00 4_00 5_00 6_00 7_00 8_00 {
	gen reg_`x' = . 
}

/*Set the number of observations*/
set obs 46

/*Fill in regulation variable labels*/
local list1 `""WRLURI 1km" "WRLURI 500m" "LLLA 1km" "DRI 1km" "OSI 1km""'
local i = 1
foreach x in 1 11 18 25 32 {
	local name1 : word `i' of `list1'
	replace bins = "`name1'" in `x'
	local i = `i' + 1
}

/*Fill in temp1 bin and control labels*/
#delimit ;
local list1 `""1>x>.5, .1>x>0" ".5>x>.25, .25>x>0" ".5>x>.25, .1>x>0" ".5>x>.25, .25>x>0" ".5>x>.25, .1>x>0" 
	".5>x>.25, .25>x>0" ".5>x>.25, .1>x>0" ".5>x>.25, .25>x>0" ".5>x>.25, .1>x>0" ".5>x>.25, .25>x>0" 
	".5>x>.25, .1>x>0""';
#delimit cr
local list2 `""1" "2" "3" "2" "3" "2" "3" "2" "3" "2" "3""'
local i = 1
foreach x in 2 5 8 12 15 19 22 26 29 33 36 {
	local name1 : word `i' of `list1' 
	local name2 : word `i' of `list2' 
	replace bins = "`name1'" in `x' 
	replace temp1 = "`name2'" in `x' 
	local i = `i' + 1
}

/*Fill in temp2 to define straight border samples*/
local list1 `""1km" "1km" "1km" "500m" "500m" "1km" "1km" "1km" "1km" "1km" "1km""'
local i = 1
foreach x in 2 5 8 12 15 19 22 26 29 33 36 {
	local name1 : word `i' of `list1'
	replace temp2 = "`name1'" in `x' 
	local i = `i' + 1
}

/*Fill in temp3 to define regulation variables*/
#delimit ;
local list1 `""d_wrluri" "d_wrluri" "d_wrluri" "d_wrluri" "d_wrluri" "d_llla" "d_llla" "d_dri" "d_dri" 
	"d_osi" "d_osi""';
#delimit cr
local i = 1
foreach x in 2 5 8 12 15 19 22 26 29 33 36 {
	local name1 : word `i' of `list1'
	replace temp3 = "`name1'" in `x' 
	local i = `i' + 1
}

/*Fill in control labels*/
#delimit ;
local list3 `""Municipality-border FE" "Quarter dummies" "Per pupil expenditures" 
	"Property taxes per acre" "Demographics" "Parcel controls I" "Parcel controls II" 
	"Interior dummy""';
#delimit cr
local list4 `""fe" "c1" "c2" "c3" "c4" "c5" "c6" "c7""'
local i = 1
forvalues x = 39/46 {
	local name3 : word `i' of `list3' 
	local name4 : word `i' of `list4'
	replace bins = "`name3'" in `x' 
	replace temp1 = "`name4'" in `x' 
	local i = `i' + 1 
}

/*Fill in the table*/
local N = _N
forvalues reg = 1/8 {
	foreach straight in 500m 1km {
		foreach regvar in d_wrluri d_llla d_dri d_osi {
			foreach yr in 00 90 {
				foreach bin in 1 2 3 {
					forvalues x = 1/`N' {
						if "`bin'" == temp1[`x'] & "`straight'" == temp2[`x'] & ///
							"`regvar'" == temp3[`x'] {
							local y = `x' + 1
							local z = `x' + 2
							capture replace reg_`reg'_`yr' = ///
								`b_`reg'_`yr'_`regvar'_`straight'_`bin'' in `x' 
							capture replace reg_`reg'_`yr' = ///
								`sd_`reg'_`yr'_`regvar'_`straight'_`bin'' in `y' 
							capture replace reg_`reg'_`yr' = ///
								`obs_`reg'_`yr'_`regvar'_`straight'_`bin'' in `z' 
						}
					}
				}
				foreach control in fe c1 c2 c3 c4 c5 c6 c7 {
					forvalues x = 1/`N' {
						if "`control'" == temp1[`x'] {
							capture replace reg_`reg'_`yr' = ///
								``control'_`reg'_`yr'_`regvar'_`straight'' in `x' 
						}
					}
				}
			}
		}
	}
}

/*Convert variables to strings and round*/
foreach x in 1_00 2_00 3_00 4_00 5_00 6_00 7_00 8_00 {
	tostring reg_`x', replace force format(%10.2f)
	foreach y in 4 7 10 14 17 21 24 28 31 35 38 39 40 41 42 43 44 45 46 {
		replace reg_`x' = subinstr(reg_`x'[`y'], ".00", "", .) in `y' 
	}
}

/*Add in group (border) observation counts and significance stars*/
local N = _N
forvalues reg = 1/8 {
	local yr 00
	foreach straight in 500m 1km {
		foreach regvar in d_wrluri d_llla d_dri d_osi {
			foreach bin in 1 2 3 {
				forvalues x = 1/`N' {
					if "`bin'" == temp1[`x'] & "`straight'" == temp2[`x'] & ///
						"`regvar'" == temp3[`x'] {
						local y = `x' + 1
						local z = `x' + 2
						local sd = reg_`reg'_`yr'[`y']
						local p = `p_`reg'_`yr'_`regvar'_`straight'_`bin''
						if `p' > 0.1 {
							capture replace reg_`reg'_`yr' = ///
								"(" + "`sd'" + ")" in `y' 
						}
						if `p' <= 0.1 & `p' > 0.05 {
							local star "*"
							capture replace reg_`reg'_`yr' = ///
								"(" + "`sd'" + ")" + "`star'" in `y' 
						}
						if `p' <= 0.05 & `p' > 0.01 {
							local star "**"
							capture replace reg_`reg'_`yr' = ///
								"(" + "`sd'" + ")" + "`star'" in `y' 
						}	
						if `p' <= 0.01 { 
							local star "***"
							capture replace reg_`reg'_`yr' = ///
								"(" + "`sd'" + ")" + "`star'" in `y' 
						}					
						local obs = reg_`reg'_`yr'[`z']
						capture replace reg_`reg'_`yr' = "`obs'" + "/" + ///
							"`g_`reg'_`yr'_`regvar'_`straight'_`bin''" in `z' 
					}
				}
			}
		}
	}
}

/*Replace missing values "." with spaces ""*/
foreach reg in 1_00 2_00 3_00 4_00 5_00 6_00 7_00 8_00 {
	replace reg_`reg' = "" if reg_`reg' == "."
}

/*Replace controls = 1 with controls = Y*/
local N = _N
foreach reg in 1_00 2_00 3_00 4_00 5_00 6_00 7_00 8_00 {
	forvalues x = 39/`N' {
		if reg_`reg'[`x'] == "1" {
			replace reg_`reg' = "Y" in `x' 
		}
		if reg_`reg'[`x'] == "0" {
			replace reg_`reg' = "" in `x' 
		}
	}
}

/*Save file*/
drop temp*
export excel using table6_externaleffect.xls, replace


**************************************************************************************************************
* Table 7 - External Effect regressions, robustness to sample timing and quarterly dummies
**************************************************************************************************************

use parcel_data, clear

/*Control variable lists*/
global parcel1 land landsq log_cbd_dist log_cbd_dist2 us990_tri us990_tri_5km us990_tri_10km
global parcel2 emp94 emp94_5km emp94_10km dev90 dev90_5km dev90_10km 
global own_demo own_black own_asian own_pop_under17 own_edu_hs own_edu_bs own_med_hh_inc 
global ex_demo d_int_black d_int_asian d_int_edu_hs d_int_edu_bs d_int_med_hh_inc 

/*Distance threshold*/
global dist = 0.1

/*Tag all parcels = 1 if they are attached to borders for which some parcel is less than $dist from a 
straight line border*/
sort border_code nbr_dist
by border_code : egen min_dist_straight = min(nbr_dist) if straight_new_dis_noc1km == 1
gen border_straight_temp = (min_dist_straight < $dist)
by border_code : egen border_straight = max(border_straight_temp) 
drop border_straight_temp min_dist_straight

/*Thresholds for bins*/
global bins "0.5 0.25 0.25"
global interior1 = real(word("$bins", 1))
global interior2 = real(word("$bins", 2))
global peripheral1 = real(word("$bins", 3))

/*Create indicator variables = 1 if parcel is in each interior bin & interact these with the regulation 
variable*/
gen int_flag = 1 if nbr_dist < $interior1 & nbr_dist > $interior2
replace int_flag = 0 if int_flag == . 
gen d_wrluri_int = d_wrluri * int_flag

/*Construct change in demograhics variables interacted with interior parcel dummy to use as demographic 
controls*/
foreach cat in black asian edu_hs edu_bs med_hh_inc {
	gen d_int_`cat' = (own_`cat' - nbr_`cat') * int_flag
}

/*Construct change in school/local finance variables interacted with interior parcel dummy*/
foreach var in pp_expend ptax {
	gen d_int_`var' = (own_mean_`var' - nbr_mean_`var') * int_flag
}

**************************************************************************************************************
* CONDITIONAL STATEMENTS AND GENERAL SAMPLE RESTRICTIONS
**************************************************************************************************************

/*Conditional statements*/
global if_own "(nbr_dist < $dist) & (border_straight == 1)"
global if_ex "((nbr_dist < $peripheral1) | (nbr_dist < $interior1 & nbr_dist > $interior2))"

/*General sample restrictions*/
drop if straight_new_dis_noc1km == 0 

xtset muni_border_code

**************************************************************************************************************
* EXTERNAL EFFECT REGRESSIONS
**************************************************************************************************************

foreach yr in 00 03 {

	/*Restrict date range*/
	preserve
	drop if own_wrluri == . 
	drop if year_lt`yr' > 0 
	if `yr' == 00 {
		drop q19832 - q19994
	}
	if `yr' == 03 {
		drop q19832 - q20024
	}
	
	/*Regression A1*/
	local reg a1
	disp "Reg = `reg' and year = `yr'"
	xi: xtreg pricepersflandgross d_wrluri_int d_int_pp_expend d_int_ptax q* ///
		if $if_ex, fe robust cluster (muni_border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`yr' = b[1,1]
	local sd_`reg'_`yr' = sqrt(v[1,1])
	local t_`reg'_`yr' = `b_`reg'_`yr'' / `sd_`reg'_`yr''
	local p_`reg'_`yr' = 2 * ttail(e(df_r), abs(`t_`reg'_`yr''))
	local fe_`reg' = 1 // fixed effects
	local c1_`reg' = 1 // quarterly dummies
	local c2_`reg' = 1 // per pupil expenditures 
	local c3_`reg' = 1 // property taxes 
	local c4_`reg' = 0 // demographics   
	local c5_`reg' = 0 // parcel I controls
	local c6_`reg' = 0 // parcel II controls 
	local c7_`reg' = 0 // interior dummy

	/*Regression A2*/
	local reg a2
	disp "Reg = `reg' and year = `yr'"
	xi: xtreg pricepersflandgross d_wrluri_int d_int_pp_expend d_int_ptax ///
		if $if_ex, fe robust cluster (muni_border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`yr' = b[1,1]
	local sd_`reg'_`yr' = sqrt(v[1,1])
	local t_`reg'_`yr' = `b_`reg'_`yr'' / `sd_`reg'_`yr''
	local p_`reg'_`yr' = 2 * ttail(e(df_r), abs(`t_`reg'_`yr''))
	local fe_`reg' = 1 // fixed effects
	local c1_`reg' = 0 // quarterly dummies
	local c2_`reg' = 1 // per pupil expenditures 
	local c3_`reg' = 1 // property taxes 
	local c4_`reg' = 0 // demographics   
	local c5_`reg' = 0 // parcel I controls
	local c6_`reg' = 0 // parcel II controls 
	local c7_`reg' = 0 // interior dummy

	/*Regression B1*/
	local reg b1
	disp "Reg = `reg' and year = `yr'"
	xi: xtreg pricepersflandgross d_wrluri_int $ex_demo $parcel1 q* ///
		if $if_ex, fe robust cluster (muni_border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`yr' = b[1,1]
	local sd_`reg'_`yr' = sqrt(v[1,1])
	local t_`reg'_`yr' = `b_`reg'_`yr'' / `sd_`reg'_`yr''
	local p_`reg'_`yr' = 2 * ttail(e(df_r), abs(`t_`reg'_`yr''))
	local fe_`reg' = 1 // fixed effects
	local c1_`reg' = 1 // quarterly dummies
	local c2_`reg' = 0 // per pupil expenditures 
	local c3_`reg' = 0 // property taxes 
	local c4_`reg' = 1 // demographics   
	local c5_`reg' = 1 // parcel I controls
	local c6_`reg' = 0 // parcel II controls 
	local c7_`reg' = 0 // interior dummy

	/*Regression B2*/
	local reg b2
	disp "Reg = `reg' and year = `yr'"
	xi: xtreg pricepersflandgross d_wrluri_int $ex_demo $parcel1 ///
		if $if_ex, fe robust cluster (muni_border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`yr' = b[1,1]
	local sd_`reg'_`yr' = sqrt(v[1,1])
	local t_`reg'_`yr' = `b_`reg'_`yr'' / `sd_`reg'_`yr''
	local p_`reg'_`yr' = 2 * ttail(e(df_r), abs(`t_`reg'_`yr''))
	local fe_`reg' = 1 // fixed effects
	local c1_`reg' = 0 // quarterly dummies
	local c2_`reg' = 0 // per pupil expenditures 
	local c3_`reg' = 0 // property taxes 
	local c4_`reg' = 1 // demographics   
	local c5_`reg' = 1 // parcel I controls
	local c6_`reg' = 0 // parcel II controls 
	local c7_`reg' = 0 // interior dummy
	
	/*Regression C1*/
	local reg c1
	disp "Reg = `reg' and year = `yr'"
	xi: xtreg pricepersflandgross d_wrluri_int d_int_pp_expend d_int_ptax $ex_demo int_flag q* ///
		if $if_ex, fe robust cluster (muni_border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`yr' = b[1,1]
	local sd_`reg'_`yr' = sqrt(v[1,1])
	local t_`reg'_`yr' = `b_`reg'_`yr'' / `sd_`reg'_`yr''
	local p_`reg'_`yr' = 2 * ttail(e(df_r), abs(`t_`reg'_`yr''))
	local fe_`reg' = 1 // fixed effects
	local c1_`reg' = 1 // quarterly dummies
	local c2_`reg' = 1 // per pupil expenditures 
	local c3_`reg' = 1 // property taxes 
	local c4_`reg' = 1 // demographics   
	local c5_`reg' = 0 // parcel I controls
	local c6_`reg' = 0 // parcel II controls 
	local c7_`reg' = 1 // interior dummy
	
	/*Regression C2*/
	local reg c2 
	disp "Reg = `reg' and year = `yr'"
	xi: xtreg pricepersflandgross d_wrluri_int d_int_pp_expend d_int_ptax $ex_demo int_flag ///
		if $if_ex, fe robust cluster (muni_border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`yr' = b[1,1]
	local sd_`reg'_`yr' = sqrt(v[1,1])
	local t_`reg'_`yr' = `b_`reg'_`yr'' / `sd_`reg'_`yr''
	local p_`reg'_`yr' = 2 * ttail(e(df_r), abs(`t_`reg'_`yr''))
	local fe_`reg' = 1 // fixed effects
	local c1_`reg' = 0 // quarterly dummies
	local c2_`reg' = 1 // per pupil expenditures 
	local c3_`reg' = 1 // property taxes 
	local c4_`reg' = 1 // demographics   
	local c5_`reg' = 0 // parcel I controls
	local c6_`reg' = 0 // parcel II controls 
	local c7_`reg' = 1 // interior dummy
	restore
}

**************************************************************************************************************
* BUILD REGRESSION TABLE
**************************************************************************************************************

/*Generate variables for table*/
clear
gen yr = ""
gen temp = ""
foreach x in a1 a2 b1 b2 c1 c2 {
	gen reg_`x' = . 
}

/*Set the number of observations*/
set obs 13

/*Fill in variable and control labels*/
local list1 `""[2000-2009]" "[2003-2009]""'
forvalues x = 1/1 {
	replace yr = "WRLURI 1km (.5>x>.25, .25>x>0)" in `x' 
}
local i = 1
forvalues x = 2(2)4 {
	local name1 : word `i' of `list1'
	replace yr = "`name1'" in `x'
	local i = `i' + 1
}
#delimit ;
local list2 `""Municipality-border FE" "Quarter dummies" "Per pupil expenditures" "Property taxes per acre" 
	"Demographics" "Parcel controls I" "Parcel controls II"  "Interior dummy""';
#delimit cr
local i = 1 
forvalues x = 6/13 {
	local name2 : word `i' of `list2'
	replace yr = "`name2'" in `x' 
	local i = `i' + 1
}

/*Fill in temporary variable*/
local list1 `""00" "03""'
local list2 `""fe" "c1" "c2" "c3" "c4" "c5" "c6" "c7""'
local i = 1
forvalues x = 2(2)6 {
	local name1 : word `i' of `list1'
	replace temp = "`name1'" in `x'
	local i = `i' + 1
}
local i = 1
forvalues x = 6/13 {
	local name2 : word `i' of `list2'
	replace temp = "`name2'" in `x'
	local i = `i' + 1
}

/*Fill in the table*/
local N = _N 
foreach reg in a1 a2 b1 b2 c1 c2 {
	foreach yr in 00 03 {
		forvalues x = 1/`N' {
			if "`yr'" == temp[`x'] {
				local y = `x' + 1 
				capture replace reg_`reg' = `b_`reg'_`yr'' in `x' 
				capture replace reg_`reg' = `sd_`reg'_`yr'' in `y' 
			}
		}
	}
	foreach control in fe c1 c2 c3 c4 c5 c6 c7 {
		forvalues x = 1/`N' {
			if "`control'" == temp[`x'] {
				capture replace reg_`reg' = ``control'_`reg'' in `x' 
			}
		}
	}
}

/*Add column labels and convert variables to strings*/
local list1 `""(1)" "(2)" "(3)" "(4)" "(5)" "(6)""'
local i = 1 
foreach x in a1 a2 b1 b2 c1 c2 {
	tostring reg_`x', replace force format(%10.2f)
	local name1 : word `i' of `list1'
	replace reg_`x' = "`name1'" in 1
	local i = `i' + 1
}

/*Add in significance stars*/
local N = _N
foreach reg in a1 a2 b1 b2 c1 c2 {
	foreach yr in 00 03 {
		forvalues x = 1/`N' {	
			if "`yr'" == temp[`x'] {
				local y = `x' + 1
				local sd = reg_`reg'[`y'] 
				capture local p = `p_`reg'_`yr''
				if `p' > 0.1 {
					capture replace reg_`reg' = "(" + "`sd'" + ")" in `y' 
				}
				if `p' <= 0.1 & `p' > 0.05 {
					local star "*"
					capture replace reg_`reg' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}
				if `p' <= 0.05 & `p' > 0.01 {
					local star "**"
					capture replace reg_`reg' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}	
				if `p' <= 0.01 { 
					local star "***"
					capture replace reg_`reg' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}		
			}
		}
	}
}

/*Replace controls = 1 with controls = Y*/
local N = _N
foreach reg in a1 a2 b1 b2 c1 c2 {
	forvalues x = 6/`N' {
		if reg_`reg'[`x'] == "1.00" {
			replace reg_`reg' = "Y" in `x' 
		}
		if reg_`reg'[`x'] == "0.00" {
			replace reg_`reg' = "" in `x' 
		}
	}
}

drop temp

export excel using table7_externaleffect_robustness_timing.xls, replace


**************************************************************************************************************
* Table 8 - External Effect regressions, robustness to demographics
**************************************************************************************************************
use parcel_data, clear

/*Control variable lists*/
global parcel1 land landsq log_cbd_dist log_cbd_dist2 us990_tri us990_tri_5km us990_tri_10km
global parcel2 emp94 emp94_5km emp94_10km dev90 dev90_5km dev90_10km 
global own_demo own_black own_asian own_pop_under17 own_edu_hs own_edu_bs own_med_hh_inc 
global ex_demo d_int_black d_int_asian d_int_edu_hs d_int_edu_bs d_int_med_hh_inc 

/*Distance threshold*/
global dist = 0.1

/*Tag all parcels = 1 if they are attached to borders for which some parcel is less than $dist from a 
straight line border*/
sort border_code nbr_dist
by border_code : egen min_dist_straight = min(nbr_dist) if straight_new_dis_noc1km == 1
gen border_straight_temp = (min_dist_straight < $dist)
by border_code : egen border_straight = max(border_straight_temp) 
drop border_straight_temp min_dist_straight

/*Thresholds for bins*/
global bins "0.5 0.25 0.25"
global interior1 = real(word("$bins", 1))
global interior2 = real(word("$bins", 2))
global peripheral1 = real(word("$bins", 3))

/*Create indicator variables = 1 if parcel is in each interior bin & interact these with the regulation 
variable*/
gen int_flag = 1 if nbr_dist < $interior1 & nbr_dist > $interior2
replace int_flag = 0 if int_flag == . 
gen d_wrluri_int = d_wrluri * int_flag

/*Create squared and log demographic variables*/
gen own_log_med_hh_inc = log(own_med_hh_inc)
gen nbr_log_med_hh_inc = log(nbr_med_hh_inc)
foreach var in own_black own_asian own_pop_under17 own_edu_hs own_edu_bs own_med_hh_inc {
	gen `var'2 = `var' * `var' 
}

/*Construct change in demograhics variables interacted with interior parcel dummy to use as demographic 
controls*/
foreach cat in black asian edu_hs edu_bs med_hh_inc log_med_hh_inc {
	gen d_int_`cat' = (own_`cat' - nbr_`cat') * int_flag
	gen d_int_`cat'2 = d_int_`cat' * d_int_`cat'
}

/*Construct change in school/local finance variables interacted with interior parcel dummy*/
foreach var in pp_expend ptax pt_ratio {
	gen d_int_`var' = (own_mean_`var' - nbr_mean_`var') * int_flag
}

**************************************************************************************************************
* CONDITIONAL STATEMENTS AND GENERAL SAMPLE RESTRICTIONS
**************************************************************************************************************

/*Conditional statements*/
global if_own "(nbr_dist < $dist) & (border_straight == 1)"
global if_ex "((nbr_dist < $peripheral1) | (nbr_dist < $interior1 & nbr_dist > $interior2))"

/*General sample restrictions*/
drop if straight_new_dis_noc1km == 0 

xtset muni_border_code

**************************************************************************************************************
* EXTERNAL EFFECT REGRESSIONS (2000-2009)
**************************************************************************************************************

/*Restrict date range*/
drop if d_wrluri == . 
drop if year_lt00 > 0 
drop q19832 - q19994

global control_a d_int_pp_expend d_int_ptax $ex_demo
global control_b d_int_pp_expend d_int_ptax $ex_demo $parcel1
global control_c d_int_pp_expend d_int_ptax $ex_demo int_flag

//global c_a 1 1 1 1 1 0 0 0
global c_a 1 1 1 1 0 0 0 0 
//global c_b 1 1 1 1 1 1 0 0
global c_b 1 1 0 0 1 1 0 0 
global c_c 1 1 1 1 1 0 0 1

foreach x in a b c {

	/*Controls*/
	local fe_`x' : word 1 of ${c_`x'} 
	local c1_`x' : word 2 of ${c_`x'}
	local c2_`x' : word 3 of ${c_`x'}
	local c3_`x' : word 4 of ${c_`x'}
	local c4_`x' : word 5 of ${c_`x'}
	local c5_`x' : word 6 of ${c_`x'}
	local c6_`x' : word 7 of ${c_`x'}
	local c7_`x' : word 8 of ${c_`x'}

	/*Regression 1*/
	//global control_a d_int_pt_ratio d_int_ptax $ex_demo
   global control_a d_int_pt_ratio d_int_ptax
	//global control_b d_int_pt_ratio d_int_ptax $ex_demo $parcel1
   global control_b d_int_pt_ratio $ex_demo $parcel1
	global control_c d_int_pt_ratio d_int_ptax $ex_demo int_flag
	local reg 1
	disp "Reg = `reg' and control group = `x'"
	xi: xtreg pricepersflandgross d_wrluri_int ${control_`x'} q* if $if_ex, fe robust cluster (muni_border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`x'= b[1,1]
	local sd_`reg'_`x'= sqrt(v[1,1])
	local t_`reg'_`x'= `b_`reg'_`x'' / `sd_`reg'_`x''
	local p_`reg'_`x'= 2 * ttail(e(df_r), abs(`t_`reg'_`x''))
	
	/*Regression 2*/
   //global control_a d_int_pp_expend d_int_ptax $ex_demo
   global control_a d_int_pp_expend d_int_ptax
	//global control_b d_int_pp_expend d_int_ptax $ex_demo $parcel1
   global control_b $ex_demo $parcel1
	global control_c d_int_pp_expend d_int_ptax $ex_demo int_flag

	local reg 2
	disp "Reg = `reg' and control group = `x'"
	xi: xtreg pricepersflandgross d_wrluri_int ${control_`x'} d_int_pt_ratio q* if $if_ex, ///
		fe robust cluster (muni_border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`x'= b[1,1]
	local sd_`reg'_`x'= sqrt(v[1,1])
	local t_`reg'_`x'= `b_`reg'_`x'' / `sd_`reg'_`x''
	local p_`reg'_`x'= 2 * ttail(e(df_r), abs(`t_`reg'_`x''))

	/*Regression 3*/
	global ex_demo d_int_black d_int_asian d_int_edu_hs d_int_edu_bs d_int_log_med_hh_inc 
	//global control_a d_int_pp_expend d_int_ptax $ex_demo
   global control_a d_int_pp_expend d_int_ptax
	//global control_b d_int_pp_expend d_int_ptax $ex_demo $parcel1
   global control_b  $ex_demo $parcel1
	global control_c d_int_pp_expend d_int_ptax $ex_demo int_flag
	local reg 3
	disp "Reg = `reg' and control group = `x'"
	xi: xtreg pricepersflandgross d_wrluri_int ${control_`x'} q* if $if_ex, fe robust cluster (muni_border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`x'= b[1,1]
	local sd_`reg'_`x'= sqrt(v[1,1])
	local t_`reg'_`x'= `b_`reg'_`x'' / `sd_`reg'_`x''
	local p_`reg'_`x'= 2 * ttail(e(df_r), abs(`t_`reg'_`x''))
	global ex_demo d_int_black d_int_asian d_int_edu_hs d_int_edu_bs d_int_med_hh_inc 
	//global control_a d_int_pp_expend d_int_ptax $ex_demo
   global control_a d_int_pp_expend d_int_ptax
	//global control_b d_int_pp_expend d_int_ptax $ex_demo $parcel1
   global control_b  $ex_demo $parcel1
	global control_c d_int_pp_expend d_int_ptax $ex_demo int_flag

	/*Regression 4*/
	local reg 4
	disp "Reg = `reg' and control group = `x'"
	xi: xtreg pricepersflandgross d_wrluri_int ${control_`x'} d_int_med_hh_inc2 q* if $if_ex, ///
		fe robust cluster (muni_border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`x'= b[1,1]
	local sd_`reg'_`x'= sqrt(v[1,1])
	local t_`reg'_`x'= `b_`reg'_`x'' / `sd_`reg'_`x''
	local p_`reg'_`x'= 2 * ttail(e(df_r), abs(`t_`reg'_`x''))

	/*Regression 5*/
	local reg 5
	disp "Reg = `reg' and control group = `x'"
	xi: xtreg pricepersflandgross d_wrluri_int ${control_`x'} d_int_black2 d_int_asian2 d_int_edu_hs2 ///
		d_int_edu_bs2 d_int_med_hh_inc2 q* if $if_ex, fe robust cluster (muni_border_code)
	matrix b = e(b)
	matrix v = e(V)
	local b_`reg'_`x'= b[1,1]
	local sd_`reg'_`x'= sqrt(v[1,1])
	local t_`reg'_`x'= `b_`reg'_`x'' / `sd_`reg'_`x''
	local p_`reg'_`x'= 2 * ttail(e(df_r), abs(`t_`reg'_`x''))
}

**************************************************************************************************************
* BUILD REGRESSION TABLE
**************************************************************************************************************

/*Generate variables for table*/
clear
gen spec = ""
gen temp = ""
foreach x in a b c {
	gen reg_`x' = . 
}

/*Set the number of observations*/
set obs 20

/*Fill in variable labels*/
forvalues x = 1/1 {
	replace spec = "WRLURI 1km (.5>x>.25, .25>x>0)" in `x' 
}
local i = 1
#delimit ; 
local list1 `""Sub P/T ratio for PP-expenditures" "Add P/T ratio" "Sub log income for income" 
	"Add income^2" "Add demographic quadratic terms""';
local list2 `""Municipality-border FE" "Quarter dummies" "Per pupil expenditures" "Property taxes per acre"
	"Demographics" "Parcel controls I" "Parcel controls II"  "Interior dummy""';
#delimit cr
forvalues x = 2(2)10 {
	local name1 : word `i' of `list1'
	replace spec = "`name1'" in `x'
	local i = `i' + 1
}
replace spec = "Initial controls" in 12
local i = 1 
forvalues x = 13/20 {
	local name2 : word `i' of `list2'
	replace spec = "`name2'" in `x' 
	local i = `i' + 1
}

/*Fill in temporary variable*/
local i = 1
forvalues x = 2(2)12 {
	replace temp = "`i'" in `x'
	local i = `i' + 1
}
local i = 1 
local list1 `""fe" "c1" "c2" "c3" "c4" "c5" "c6" "c7""'
forvalues x = 13/20 {
	local name1 : word `i' of `list1'
	replace temp = "`name1'" in `x' 
	local i = `i' + 1
}

/*Fill in the table*/
local N = _N
foreach spec in a b c {
	forvalues reg = 1/5 {
		forvalues x = 1/`N' {
			if "`reg'" == temp[`x'] {
				local y = `x' + 1 
				capture replace reg_`spec' = `b_`reg'_`spec'' in `x' 
				capture replace reg_`spec' = `sd_`reg'_`spec'' in `y'
			}
		}
	}
	foreach control in fe c1 c2 c3 c4 c5 c6 c7 {
		forvalues x = 1/`N' {
			if "`control'" == temp[`x'] {
				capture replace reg_`spec' = ``control'_`spec'' in `x' 
			}
		}
	}
}

/*Add column labels and convert variables to strings*/
local list1 `""(1)" "(2)" "(3)""'
local i = 1 
foreach x in a b c {
	tostring reg_`x', replace force format(%10.2f)
	local name1 : word `i' of `list1'
	replace reg_`x' = "`name1'" in 1 
	local i = `i' + 1
}

/*Add in significance stars*/
local N = _N
forvalues reg = 1/5 {
	foreach spec in a b c {
		forvalues x = 1/`N' {
			if "`reg'" == temp[`x'] {
				local y = `x' + 1
				local sd = reg_`spec'[`y'] 
				capture local p = `p_`reg'_`spec''
				if `p' > 0.1 {
					capture replace reg_`spec' = "(" + "`sd'" + ")" in `y' 
				}
				if `p' <= 0.1 & `p' > 0.05 {
					local star "*"
					capture replace reg_`spec' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}
				if `p' <= 0.05 & `p' > 0.01 {
					local star "**"
					capture replace reg_`spec' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}	
				if `p' <= 0.01 { 
					local star "***"
					capture replace reg_`spec' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}		
			}
		}
	}
}

/*Replace controls = 1 with controls = Y*/
local N = _N
foreach reg in a b c {
	forvalues x = 13/`N' {
		if reg_`reg'[`x'] == "1.00" {
			replace reg_`reg' = "Y" in `x' 
		}
		if reg_`reg'[`x'] == "0.00" {
			replace reg_`reg' = "" in `x' 
		}
	}
	replace reg_`reg' = "" if reg_`reg' == "." 
}

/*Save file*/
drop temp
export excel using table8_externaleffect_robustness_demo.xls, replace


**************************************************************************************************************
* Table 9 - External Effect regressions, robustness to functional form
**************************************************************************************************************
use parcel_data, clear

/*Control variable lists*/
global parcel1 land landsq log_cbd_dist log_cbd_dist2 us990_tri us990_tri_5km us990_tri_10km
global parcel2 emp94 emp94_5km emp94_10km dev90 dev90_5km dev90_10km 
global own_demo own_black own_asian own_pop_under17 own_edu_hs own_edu_bs own_med_hh_inc 
global ex_demo d_int_black d_int_asian d_int_edu_hs d_int_edu_bs d_int_med_hh_inc 

/*Distance threshold*/
global dist = 0.1

/*Tag all parcels = 1 if they are attached to borders for which some parcel is less than $dist from a 
straight line border*/
sort border_code nbr_dist
by border_code : egen min_dist_straight = min(nbr_dist) if straight_new_dis_noc1km == 1
gen border_straight_temp = (min_dist_straight < $dist)
by border_code : egen border_straight = max(border_straight_temp) 
drop border_straight_temp min_dist_straight

/*Thresholds for bins*/
global bins "0.5 0.25 0.25"
global interior1 = real(word("$bins", 1))
global interior2 = real(word("$bins", 2))
global peripheral1 = real(word("$bins", 3))

/*Create indicator variables = 1 if parcel is in each interior bin & interact these with the regulation 
variable*/
gen int_flag = 1 if nbr_dist < $interior1 & nbr_dist > $interior2
replace int_flag = 0 if int_flag == . 
foreach var in wrluri llla dri osi {
	gen d_`var'_int = d_`var' * int_flag
}

/*Create squared and log variables*/
gen own_log_med_hh_inc = log(own_med_hh_inc)
gen nbr_log_med_hh_inc = log(nbr_med_hh_inc)
foreach var in own_black own_asian own_pop_under17 own_edu_hs own_edu_bs own_med_hh_inc own_wrluri ///
	d_wrluri_int {
	gen `var'2 = `var' * `var' 
}

/*Interact regulation variables with residential dummy*/
foreach var in wrluri llla dri osi {
	gen d_`var'_int_res = d_`var'_int * residentialland
}

/*Construct change in demograhics variables interacted with interior parcel dummy to use as demographic 
controls*/
foreach cat in black asian edu_hs edu_bs med_hh_inc log_med_hh_inc {
	gen d_int_`cat' = (own_`cat' - nbr_`cat') * int_flag
}

/*Construct change in school/local finance variables interacted with interior parcel dummy*/
foreach var in pp_expend ptax {
	gen d_int_`var' = (own_mean_`var' - nbr_mean_`var') * int_flag
}

**************************************************************************************************************
* CONDITIONAL STATEMENTS AND GENERAL SAMPLE RESTRICTIONS
**************************************************************************************************************

/*Conditional statements*/
global if_own "(nbr_dist < $dist) & (border_straight == 1)"
global if_ex "((nbr_dist < $peripheral1) | (nbr_dist < $interior1 & nbr_dist > $interior2))"

/*General sample restrictions*/
drop if straight_new_dis_noc1km == 0 

xtset muni_border_code

**************************************************************************************************************
* OWN-LOT EFFECT REGRESSIONS (2000-2009)
**************************************************************************************************************

/*Restrict date range*/
drop if own_wrluri == . 
drop if year_lt00 > 0 
drop q19832 - q19994

global control_a d_int_pp_expend d_int_ptax 
global control_b $ex_demo $parcel1
global control_c d_int_pp_expend d_int_ptax $ex_demo int_flag

local clist_a 1 1 1 1 0 0 0 0 
local clist_b 1 1 0 0 1 1 0 0 
local clist_c 1 1 1 1 1 0 0 1

foreach x in a b c {

	/*Control lists*/
	local fe_`x' : word 1 of `clist_`x''
	local c1_`x' : word 2 of `clist_`x''
	local c2_`x' : word 3 of `clist_`x''
	local c3_`x' : word 4 of `clist_`x''
	local c4_`x' : word 5 of `clist_`x''
	local c5_`x' : word 6 of `clist_`x''
	local c6_`x' : word 7 of `clist_`x''
	local c7_`x' : word 8 of `clist_`x''

	/*Regression 1*/
	local reg 1
	disp "Reg = `reg' and control group = `x'"
	xi: xtreg pricepersflandgross d_wrluri_int d_wrluri_int2 ${control_`x'} q* if $if_ex, ///
		fe robust cluster (muni_border_code)
	matrix b = e(b)
	matrix v = e(V)
	forvalues y = 1/2 {
		local b`y'_`reg'_`x'= b[1,`y']
		local sd`y'_`reg'_`x'= sqrt(v[`y',`y'])
		local t`y'_`reg'_`x'= `b`y'_`reg'_`x'' / `sd`y'_`reg'_`x''
		local p`y'_`reg'_`x'= 2 * ttail(e(df_r), abs(`t`y'_`reg'_`x''))
	}
}

**************************************************************************************************************
* BUILD REGRESSION TABLE
**************************************************************************************************************

/*Generate variables for table*/
clear
gen spec = ""
gen coef = ""
gen temp1 = ""
gen temp2 = ""
foreach x in a b c {
	gen reg_`x' = . 
}

/*Set the number of observations*/
set obs 13

/*Fill in variable and control labels*/
forvalues x = 1/1 {
	replace spec = "WRLURI 1km (.5>x>.25, .25>x>0)" in `x' 
}
#delimit ;
local list1 `""Add WRLURI^2""';
local list2 `""Municipality-border FE" "Quarter dummies" "Per pupil expenditures" "Property taxes per acre"
	"Demographics" "Parcel controls I" "Parcel controls II"  "Interior dummy""';
#delimit cr
local i = 1
foreach x in 2 {
	local name1 : word `i' of `list1'
	replace spec = "`name1'" in `x'
	local i = `i' + 1
}
local i = 1 
forvalues x = 6/13 {
	local name2 : word `i' of `list2'
	replace spec = "`name2'" in `x' 
	local i = `i' + 1
}

/*Fill in temporary variables*/
local i = 1
local list1 1 1 
local list2 1 2 
local list3 `""WRLURI" "WRLURI^2""'
forvalues x = 2(2)4 {
	local name1 : word `i' of `list1'
	local name2 : word `i' of `list2' 
	local name3 : word `i' of `list3' 
	replace temp1 = "`name1'" in `x'
	replace temp2 = "`name2'" in `x' 
	replace coef = "`name3'" in `x' 
	local i = `i' + 1
}
local list4 `""fe" "c1" "c2" "c3" "c4" "c5" "c6" "c7""'
local i = 1 
forvalues x = 6/13 {
	local name4 : word `i' of `list4' 
	replace temp1 = "`name4'" in `x' 
	local i = `i' + 1 
}

/*Fill in the table*/
local N = _N
forvalues reg = 1/1 {
	foreach spec in a b c {
		foreach coef in 1 2 {
			forvalues x = 1/`N' {
				if "`reg'" == temp1[`x'] & "`coef'" == temp2[`x'] {
					local y = `x' + 1 
					capture replace reg_`spec' = `b`coef'_`reg'_`spec'' in `x' 
					capture replace reg_`spec' = `sd`coef'_`reg'_`spec'' in `y'
				}
			}
		}
		foreach control in fe c1 c2 c3 c4 c5 c6 c7 {
			forvalues x = 1/`N' {
				if "`control'" == temp1[`x'] {
					capture replace reg_`spec' = ``control'_`spec'' in `x' 
				}
			}
		}		
	}
}

/*Add column labels and convert variables to strings*/
local list1 `""(1)" "(2)" "(3)""'
local i = 1 
foreach x in a b c {
	tostring reg_`x', replace force format(%10.2f)
	local name1 : word `i' of `list1'
	replace reg_`x' = "`name1'" in 1 
	local i = `i' + 1
}
forvalues x = 1/1 {
	replace coef = "coef" in `x' 
}

/*Add in significance stars*/
local N = _N
forvalues reg = 1/1 {
	foreach spec in a b c {
		foreach coef in 1 2 {
			forvalues x = 1/`N' {
				if "`reg'" == temp1[`x'] & "`coef'" == temp2[`x'] {
					local y = `x' + 1
					local sd = reg_`spec'[`y'] 
					capture local p = `p`coef'_`reg'_`spec''
					if `p' > 0.1 {
						capture replace reg_`spec' = "(" + "`sd'" + ")" in `y' 
					}
					if `p' <= 0.1 & `p' > 0.05 {
						local star "*"
						capture replace reg_`spec' = "(" + "`sd'" + ")" + "`star'" in `y' 
					}
					if `p' <= 0.05 & `p' > 0.01 {
						local star "**"
						capture replace reg_`spec' = "(" + "`sd'" + ")" + "`star'" in `y' 
					}	
					if `p' <= 0.01 { 
					local star "***"
						capture replace reg_`spec' = "(" + "`sd'" + ")" + "`star'" in `y' 
					}
				}		
			}
		}
	}
}

/*Replace controls = 1 with controls = Y*/
local N = _N
foreach reg in a b c {
	forvalues x = 6/`N' {
		if reg_`reg'[`x'] == "1.00" {
			replace reg_`reg' = "Y" in `x' 
		}
		if reg_`reg'[`x'] == "0.00" {
			replace reg_`reg' = "" in `x' 
		}
	}
}

/*Save file*/
drop temp*
export excel using table9_externaleffect_robustness_form.xls, replace

**************************************************************************************************************
* Table A2 - All coefficients from row 3 of Table 2
**************************************************************************************************************
use parcel_data, clear

/*Control variable lists*/
global parcel1 land landsq log_cbd_dist log_cbd_dist2 us990_tri us990_tri_5km us990_tri_10km
global parcel2 emp94 emp94_5km emp94_10km dev90 dev90_5km dev90_10km 
global own_demo own_black own_asian own_edu_hs own_edu_bs own_med_hh_inc 
global ex_demo d_int_black d_int_asian d_int_edu_hs d_int_edu_bs d_int_med_hh_inc 

/*Distance threshold*/
global dist = 0.1

/*Tag all parcels = 1 if they are attached to borders for which some parcel is less than $dist from a 
straight line border*/
sort border_code nbr_dist
by border_code : egen min_dist_straight = min(nbr_dist) if straight_new_dis_noc1km == 1
gen border_straight_temp = (min_dist_straight < $dist)
by border_code : egen border_straight = max(border_straight_temp) 
drop border_straight_temp min_dist_straight

/*Thresholds for bins*/
global bins "0.5 0.25 0.25"
global interior1 = real(word("$bins", 1))
global interior2 = real(word("$bins", 2))
global peripheral1 = real(word("$bins", 3))

/*Create indicator variables = 1 if parcel is in each interior bin & interact these with the regulation 
variable*/
gen int_flag = 1 if nbr_dist < $interior1 & nbr_dist > $interior2
replace int_flag = 0 if int_flag == . 
gen d_wrluri_int = d_wrluri * int_flag

/*Construct change in demograhics variables interacted with interior parcel dummy to use as demographic 
controls*/
foreach cat in black asian edu_hs edu_bs med_hh_inc {
	gen d_int_`cat' = (own_`cat' - nbr_`cat') * int_flag
}

/*Construct change in school/local finance variables interacted with interior parcel dummy*/
foreach var in pp_expend ptax {
	gen d_int_`var' = (own_mean_`var' - nbr_mean_`var') * int_flag
}

**************************************************************************************************************
* CONDITIONAL STATEMENTS AND GENERAL SAMPLE RESTRICTIONS
**************************************************************************************************************

/*Conditional statements*/
global if_own "(nbr_dist < $dist) & (border_straight == 1)"
global if_ex "((nbr_dist < $peripheral1) | (nbr_dist < $interior1 & nbr_dist > $interior2))"

/*General sample restrictions*/
drop if straight_new_dis_noc1km == 0 

**************************************************************************************************************
* OWN-LOT EFFECT REGRESSIONS (2000-2009)
**************************************************************************************************************

/*Set up*/
preserve
drop if own_wrluri == . 
drop if year_lt00 > 0 
drop q19832 - q19994
xtset border_code

/*Regression 1*/
local reg = 1
xi: xtreg pricepersflandgross own_wrluri q* if $if_own, fe robust cluster (border_code)
matrix b = e(b)
matrix v = e(V)
local i = 1
foreach var in own_wrluri {
	local b_`reg'_`var' = b[1,`i']
	local sd_`reg'_`var' = sqrt(v[`i',`i'])
	local t_`reg'_`var' = `b_`reg'_`var'' / `sd_`reg'_`var''
	local p_`reg'_`var' = 2 * ttail(e(df_r), abs(`t_`reg'_`var''))
	local i = `i' + 1
}
local fe_`reg' = 1 // fixed effects
local c1_`reg' = 1 // quarterly dummies
local c2_`reg' = 0 // per pupil expenditures 
local c3_`reg' = 0 // property taxes 
local c4_`reg' = 0 // demographics 
local c5_`reg' = 0 // parcel I controls 
local c6_`reg' = 0 // parcel II controls 

/*Regression 2*/
local reg = 2
xi: xtreg pricepersflandgross own_wrluri own_mean_pp_expend own_mean_ptax q* if $if_own, ///
	fe robust cluster (border_code)
matrix b = e(b)
matrix v = e(V)
local i = 1
foreach var in own_wrluri own_mean_pp_expend own_mean_ptax {
	local b_`reg'_`var' = b[1,`i']
	local sd_`reg'_`var' = sqrt(v[`i',`i'])
	local t_`reg'_`var' = `b_`reg'_`var'' / `sd_`reg'_`var''
	local p_`reg'_`var' = 2 * ttail(e(df_r), abs(`t_`reg'_`var''))
	local i = `i' + 1
}
local fe_`reg' = 1 // fixed effects
local c1_`reg' = 1 // quarterly dummies
local c2_`reg' = 1 // per pupil expenditures 
local c3_`reg' = 1 // property taxes 
local c4_`reg' = 0 // demographics 
local c5_`reg' = 0 // parcel I controls 
local c6_`reg' = 0 // parcel II controls 

/*Regression 3*/
local reg = 3
xi: xtreg pricepersflandgross own_wrluri own_mean_pp_expend own_mean_ptax $own_demo q* if $if_own, ///
	fe robust cluster (border_code)
matrix b = e(b)
matrix v = e(V)
local i = 1
foreach var in own_wrluri own_mean_pp_expend own_mean_ptax $own_demo {
	local b_`reg'_`var' = b[1,`i']
	local sd_`reg'_`var' = sqrt(v[`i',`i'])
	local t_`reg'_`var' = `b_`reg'_`var'' / `sd_`reg'_`var''
	local p_`reg'_`var' = 2 * ttail(e(df_r), abs(`t_`reg'_`var''))
	local i = `i' + 1
}
local fe_`reg' = 1 // fixed effects
local c1_`reg' = 1 // quarterly dummies
local c2_`reg' = 1 // per pupil expenditures 
local c3_`reg' = 1 // property taxes 
local c4_`reg' = 1 // demographics 
local c5_`reg' = 0 // parcel I controls 
local c6_`reg' = 0 // parcel II controls 

/*Regression 4*/
local reg = 4
xi: xtreg pricepersflandgross own_wrluri own_mean_pp_expend own_mean_ptax $own_demo $parcel1 q* ///
	if $if_own, fe robust cluster (border_code)
matrix b = e(b)
matrix v = e(V)
local i = 1
foreach var in own_wrluri own_mean_pp_expend own_mean_ptax $own_demo $parcel1 {
	local b_`reg'_`var' = b[1,`i']
	local sd_`reg'_`var' = sqrt(v[`i',`i'])
	local t_`reg'_`var' = `b_`reg'_`var'' / `sd_`reg'_`var''
	local p_`reg'_`var' = 2 * ttail(e(df_r), abs(`t_`reg'_`var''))
	local i = `i' + 1
}
local fe_`reg' = 1 // fixed effects
local c1_`reg' = 1 // quarterly dummies
local c2_`reg' = 1 // per pupil expenditures 
local c3_`reg' = 1 // property taxes 
local c4_`reg' = 1 // demographics 
local c5_`reg' = 1 // parcel I controls 
local c6_`reg' = 0 // parcel II controls 

/*Regression 5*/
local reg = 5
xi: xtreg pricepersflandgross own_wrluri own_mean_pp_expend own_mean_ptax $own_demo $parcel2 q* ///
	if $if_own, fe robust cluster (border_code)
matrix b = e(b)
matrix v = e(V)
local i = 1
foreach var in own_wrluri own_mean_pp_expend own_mean_ptax $own_demo $parcel2 {
	local b_`reg'_`var' = b[1,`i']
	local sd_`reg'_`var' = sqrt(v[`i',`i'])
	local t_`reg'_`var' = `b_`reg'_`var'' / `sd_`reg'_`var''
	local p_`reg'_`var' = 2 * ttail(e(df_r), abs(`t_`reg'_`var''))
	local i = `i' + 1
}
local fe_`reg' = 1 // fixed effects
local c1_`reg' = 1 // quarterly dummies
local c2_`reg' = 1 // per pupil expenditures 
local c3_`reg' = 1 // property taxes 
local c4_`reg' = 1 // demographics 
local c5_`reg' = 0 // parcel I controls 
local c6_`reg' = 1 // parcel II controls 

/*Regression 6*/
local reg = 6
xi: xtreg pricepersflandgross own_wrluri own_mean_pp_expend own_mean_ptax $own_demo $parcel1 ///
	$parcel2 q* if $if_own, fe robust cluster (border_code)
matrix b = e(b)
matrix v = e(V)
local i = 1
foreach var in own_wrluri own_mean_pp_expend own_mean_ptax $own_demo $parcel1 $parcel2 {
	local b_`reg'_`var' = b[1,`i']
	local sd_`reg'_`var' = sqrt(v[`i',`i'])
	local t_`reg'_`var' = `b_`reg'_`var'' / `sd_`reg'_`var''
	local p_`reg'_`var' = 2 * ttail(e(df_r), abs(`t_`reg'_`var''))
	local i = `i' + 1
}
local fe_`reg' = 1 // fixed effects
local c1_`reg' = 1 // quarterly dummies
local c2_`reg' = 1 // per pupil expenditures 
local c3_`reg' = 1 // property taxes 
local c4_`reg' = 1 // demographics 
local c5_`reg' = 1 // parcel I controls 
local c6_`reg' = 1 // parcel II controls 
restore

**************************************************************************************************************
* BUILD REGRESSION TABLE
**************************************************************************************************************

/*Generate variables for table*/
clear
gen var = ""
gen temp = ""
forvalues x = 1/6 {
	gen reg_`x' = . 
}

/*Set the number of observations*/
set obs 50

/*Fill in variable and control labels*/
#delimit ;
local list1 `""own_wrluri" "own_mean_pp_expend" "own_mean_ptax" "own_black" "own_asian" 
	"own_edu_hs" "own_edu_bs" "own_med_hh_inc" "land" "landsq" "log_cbd_dist" "log_cbd_dist2" 
	"us990_tri" "us990_tri_5km" "us990_tri_10km" "emp94" "emp94_5km" "emp94_10km" "dev90" 
	"dev90_5km" "dev90_10km""';
local list2 `""Border pair FE" "Quarter dummies" "Per pupil expenditures" "Property taxes per acre"
	"Demographics" "Parcel controls I" "Parcel controls II""';
#delimit cr
forvalues x = 1/1 {
	replace var = "WRLURI 1km (dist < 0.1)" in `x' 
}
local i = 1
forvalues x = 2(2)42 {
	local name1 : word `i' of `list1'
	replace var = "`name1'" in `x'
	local i = `i' + 1
}
local i = 1 
forvalues x = 44/50 {
	local name2 : word `i' of `list2'
	replace var = "`name2'" in `x' 
	local i = `i' + 1
}

/*Fill in temporary control variables*/
local list1 `""fe" "c1" "c2" "c3" "c4" "c5" "c6""'
local i = 1
forvalues x = 44/50 {
	local name1 : word `i' of `list1'
	replace temp = "`name1'" in `x'
	local i = `i' + 1
}

/*Fill in the table*/
local N = _N
forvalues reg = 1/6 {
	foreach var in own_wrluri own_mean_pp_expend own_mean_ptax $own_demo $parcel1 $parcel2 {
		forvalues x = 1/`N' {
			if "`var'" == var[`x'] {
				local y = `x' + 1
				capture replace reg_`reg' = `b_`reg'_`var'' in `x' 
				capture replace reg_`reg' = `sd_`reg'_`var'' in `y' 
			}
		}
	}
	foreach control in fe c1 c2 c3 c4 c5 c6 {
		forvalues x = 1/`N' {
			if "`control'" == temp[`x'] {
				capture replace reg_`reg' = ``control'_`reg'' in `x' 
			}
		}
	}
}

/*Convert variables to strings and round*/
forvalues x = 1/6 {
	tostring reg_`x', replace force format(%10.2f)
}

/*Add in significance stars*/
forvalues reg = 1/6 {
	foreach var in own_wrluri own_mean_pp_expend own_mean_ptax $own_demo $parcel1 $parcel2 {
		forvalues x = 1/43 {
			if "`var'" == var[`x'] {	
				local y = `x' + 1
				local sd = reg_`reg'[`y'] 
				capture local p = `p_`reg'_`var''
				if `p' > 0.1 {
					capture replace reg_`reg' = "(" + "`sd'" + ")" in `y' 
				}
				if `p' <= 0.1 & `p' > 0.05 {
					local star "*"
					capture replace reg_`reg' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}
				if `p' <= 0.05 & `p' > 0.01 {
					local star "**"
					capture replace reg_`reg' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}	
				if `p' <= 0.01 { 
					local star "***"
					capture replace reg_`reg' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}		
			}
		}
	}
}

/*Replace missing values with spaces*/
forvalues reg = 1/6 {
	replace reg_`reg' = "" if reg_`reg' == "." | reg_`reg' == "(.)" | reg_`reg' == "(.)*" | ///
		reg_`reg' == "(.)**" | reg_`reg' == "(.)***"
}	

/*Replace controls = 1 with controls = Y*/
local N = _N
forvalues reg = 1/6 {
	forvalues x = 44/`N' {
		if reg_`reg'[`x'] == "1.00" {
			replace reg_`reg' = "Y" in `x' 
		}
		if reg_`reg'[`x'] == "0.00" {
			replace reg_`reg' = "" in `x' 
		}
	}
}			

drop temp
export excel using tableA2_all_coefs_ownlot.xls, replace

**************************************************************************************************************
* Table A3 - All coefficients from row 2 of Table 6
**************************************************************************************************************
use parcel_data, clear

/*Control variable lists*/
global parcel1 land landsq log_cbd_dist log_cbd_dist2 us990_tri us990_tri_5km us990_tri_10km
global parcel2 emp94 emp94_5km emp94_10km dev90 dev90_5km dev90_10km 
global own_demo own_black own_asian own_pop_under17 own_edu_hs own_edu_bs own_med_hh_inc 
global ex_demo d_int_black d_int_asian d_int_edu_hs d_int_edu_bs d_int_med_hh_inc 

/*Distance threshold*/
global dist = 0.1

/*Tag all parcels = 1 if they are attached to borders for which some parcel is less than $dist from a 
straight line border*/
sort border_code nbr_dist
by border_code : egen min_dist_straight = min(nbr_dist) if straight_new_dis_noc1km == 1
gen border_straight_temp = (min_dist_straight < $dist)
by border_code : egen border_straight = max(border_straight_temp) 
drop border_straight_temp min_dist_straight

/*Thresholds for bins*/
global bins "0.5 0.25 0.25"
global interior1 = real(word("$bins", 1))
global interior2 = real(word("$bins", 2))
global peripheral1 = real(word("$bins", 3))

/*Create indicator variables = 1 if parcel is in each interior bin & interact these with the regulation 
variable*/
gen int_flag = 1 if nbr_dist < $interior1 & nbr_dist > $interior2
replace int_flag = 0 if int_flag == . 
gen d_wrluri_int = d_wrluri * int_flag

/*Construct change in demograhics variables interacted with interior parcel dummy to use as demographic 
controls*/
foreach cat in black asian edu_hs edu_bs med_hh_inc {
	gen d_int_`cat' = (own_`cat' - nbr_`cat') * int_flag
}

/*Construct change in school/local finance variables interacted with interior parcel dummy*/
foreach var in pp_expend ptax {
	gen d_int_`var' = (own_mean_`var' - nbr_mean_`var') * int_flag
}

**************************************************************************************************************
* CONDITIONAL STATEMENTS AND GENERAL SAMPLE RESTRICTIONS
**************************************************************************************************************

/*Conditional statements*/
global if_own "(nbr_dist < $dist) & (border_straight == 1)"
global if_ex "((nbr_dist < $peripheral1) | (nbr_dist < $interior1 & nbr_dist > $interior2))"

/*General sample restrictions*/
drop if straight_new_dis_noc1km == 0 

**************************************************************************************************************
* EXTERNAL EFFECT REGRESSIONS (2000-2009)
**************************************************************************************************************

/*Set up*/
preserve
drop if d_wrluri == . 
drop if year_lt00 > 0 
drop q19832 - q19994
xtset muni_border_code

/*Regression 1*/
local reg = 1
xi: xtreg pricepersflandgross d_wrluri_int q* if $if_ex, fe robust cluster (muni_border_code)
matrix b = e(b)
matrix v = e(V)
local i = 1
foreach var in d_wrluri_int {
	local b_`reg'_`var' = b[1,`i']
	local sd_`reg'_`var' = sqrt(v[`i',`i'])
	local t_`reg'_`var' = `b_`reg'_`var'' / `sd_`reg'_`var''
	local p_`reg'_`var' = 2 * ttail(e(df_r), abs(`t_`reg'_`var''))
	local i = `i' + 1
}
local fe_`reg' = 1 // fixed effects
local c1_`reg' = 1 // quarterly dummies
local c2_`reg' = 0 // per pupil expenditures 
local c3_`reg' = 0 // property taxes 
local c4_`reg' = 0 // demographics 
local c5_`reg' = 0 // parcel I controls 
local c6_`reg' = 0 // parcel II controls 
local c7_`reg' = 0 // interior dummy 

/*Regression 2*/
local reg = 2
xi: xtreg pricepersflandgross d_wrluri_int d_int_pp_expend d_int_ptax q* if $if_ex, ///
	fe robust cluster (muni_border_code)
matrix b = e(b)
matrix v = e(V)
local i = 1
foreach var in d_wrluri_int d_int_pp_expend d_int_ptax {
	local b_`reg'_`var' = b[1,`i']
	local sd_`reg'_`var' = sqrt(v[`i',`i'])
	local t_`reg'_`var' = `b_`reg'_`var'' / `sd_`reg'_`var''
	local p_`reg'_`var' = 2 * ttail(e(df_r), abs(`t_`reg'_`var''))
	local i = `i' + 1
}
local fe_`reg' = 1 // fixed effects
local c1_`reg' = 1 // quarterly dummies
local c2_`reg' = 1 // per pupil expenditures 
local c3_`reg' = 1 // property taxes 
local c4_`reg' = 0 // demographics 
local c5_`reg' = 0 // parcel I controls 
local c6_`reg' = 0 // parcel II controls 
local c7_`reg' = 0 // interior dummy 

/*Regression 3*/
local reg = 3
xi: xtreg pricepersflandgross d_wrluri_int $ex_demo $parcel1 q* if $if_ex, ///
	fe robust cluster (muni_border_code)
matrix b = e(b)
matrix v = e(V)
local i = 1
foreach var in d_wrluri_int $ex_demo $parcel1 {
	local b_`reg'_`var' = b[1,`i']
	local sd_`reg'_`var' = sqrt(v[`i',`i'])
	local t_`reg'_`var' = `b_`reg'_`var'' / `sd_`reg'_`var''
	local p_`reg'_`var' = 2 * ttail(e(df_r), abs(`t_`reg'_`var''))
	local i = `i' + 1
}
local fe_`reg' = 1 // fixed effects
local c1_`reg' = 1 // quarterly dummies
local c2_`reg' = 0 // per pupil expenditures 
local c3_`reg' = 0 // property taxes 
local c4_`reg' = 1 // demographics 
local c5_`reg' = 1 // parcel I controls 
local c6_`reg' = 0 // parcel II controls 
local c7_`reg' = 0 // interior dummy 

/*Regression 4*/
local reg = 4
xi: xtreg pricepersflandgross d_wrluri_int $ex_demo $parcel1 $parcel2 int_flag ///
	q* if $if_ex, fe robust cluster (muni_border_code)
matrix b = e(b)
matrix v = e(V)
local i = 1
foreach var in d_wrluri_int $ex_demo $parcel1 $parcel2 int_flag {
	local b_`reg'_`var' = b[1,`i']
	local sd_`reg'_`var' = sqrt(v[`i',`i'])
	local t_`reg'_`var' = `b_`reg'_`var'' / `sd_`reg'_`var''
	local p_`reg'_`var' = 2 * ttail(e(df_r), abs(`t_`reg'_`var''))
	local i = `i' + 1
}
local fe_`reg' = 1 // fixed effects
local c1_`reg' = 1 // quarterly dummies
local c2_`reg' = 0 // per pupil expenditures 
local c3_`reg' = 0 // property taxes 
local c4_`reg' = 1 // demographics 
local c5_`reg' = 1 // parcel I controls 
local c6_`reg' = 1 // parcel II controls 
local c7_`reg' = 1 // interior dummy 

/*Regression 5*/
local reg = 5
xi: xtreg pricepersflandgross d_wrluri_int d_int_pp_expend d_int_ptax $ex_demo $parcel2 ///
	q* if $if_ex, fe robust cluster (muni_border_code)
matrix b = e(b)
matrix v = e(V)
local i = 1
foreach var in d_wrluri_int d_int_pp_expend d_int_ptax $ex_demo $parcel2 {
	local b_`reg'_`var' = b[1,`i']
	local sd_`reg'_`var' = sqrt(v[`i',`i'])
	local t_`reg'_`var' = `b_`reg'_`var'' / `sd_`reg'_`var''
	local p_`reg'_`var' = 2 * ttail(e(df_r), abs(`t_`reg'_`var''))
	local i = `i' + 1
}
local fe_`reg' = 1 // fixed effects
local c1_`reg' = 1 // quarterly dummies
local c2_`reg' = 1 // per pupil expenditures 
local c3_`reg' = 1 // property taxes 
local c4_`reg' = 1 // demographics 
local c5_`reg' = 0 // parcel I controls 
local c6_`reg' = 1 // parcel II controls 
local c7_`reg' = 0 // interior dummy 

/*Regression 6*/
local reg = 6
xi: xtreg pricepersflandgross d_wrluri_int d_int_pp_expend d_int_ptax $ex_demo int_flag ///
	q* if $if_ex, fe robust cluster (muni_border_code)
matrix b = e(b)
matrix v = e(V)
local i = 1
foreach var in d_wrluri_int d_int_pp_expend d_int_ptax $ex_demo int_flag {
	local b_`reg'_`var' = b[1,`i']
	local sd_`reg'_`var' = sqrt(v[`i',`i'])
	local t_`reg'_`var' = `b_`reg'_`var'' / `sd_`reg'_`var''
	local p_`reg'_`var' = 2 * ttail(e(df_r), abs(`t_`reg'_`var''))
	local i = `i' + 1
}
local fe_`reg' = 1 // fixed effects
local c1_`reg' = 1 // quarterly dummies
local c2_`reg' = 1 // per pupil expenditures 
local c3_`reg' = 1 // property taxes 
local c4_`reg' = 1 // demographics 
local c5_`reg' = 0 // parcel I controls 
local c6_`reg' = 0 // parcel II controls 
local c7_`reg' = 1 // interior dummy 

/*Regression 7*/
local reg = 7
xi: xtreg pricepersflandgross d_wrluri_int d_int_pp_expend d_int_ptax $ex_demo $parcel1 ///
	$parcel2 q* if $if_ex, fe robust cluster (muni_border_code)
matrix b = e(b)
matrix v = e(V)
local i = 1
foreach var in d_wrluri_int d_int_pp_expend d_int_ptax $ex_demo $parcel1 $parcel2 {
	local b_`reg'_`var' = b[1,`i']
	local sd_`reg'_`var' = sqrt(v[`i',`i'])
	local t_`reg'_`var' = `b_`reg'_`var'' / `sd_`reg'_`var''
	local p_`reg'_`var' = 2 * ttail(e(df_r), abs(`t_`reg'_`var''))
	local i = `i' + 1
}
local fe_`reg' = 1 // fixed effects
local c1_`reg' = 1 // quarterly dummies
local c2_`reg' = 1 // per pupil expenditures 
local c3_`reg' = 1 // property taxes 
local c4_`reg' = 1 // demographics 
local c5_`reg' = 1 // parcel I controls 
local c6_`reg' = 1 // parcel II controls 
local c7_`reg' = 0 // interior dummy 

/*Regression 8*/
local reg = 8
xi: xtreg pricepersflandgross d_wrluri_int d_int_pp_expend d_int_ptax $ex_demo $parcel1 ///
	$parcel2 int_flag q* if $if_ex, fe robust cluster (muni_border_code)
matrix b = e(b)
matrix v = e(V)
local i = 1
foreach var in d_wrluri_int d_int_pp_expend d_int_ptax $ex_demo $parcel1 $parcel2 int_flag {
	local b_`reg'_`var' = b[1,`i']
	local sd_`reg'_`var' = sqrt(v[`i',`i'])
	local t_`reg'_`var' = `b_`reg'_`var'' / `sd_`reg'_`var''
	local p_`reg'_`var' = 2 * ttail(e(df_r), abs(`t_`reg'_`var''))
	local i = `i' + 1
}
local fe_`reg' = 1 // fixed effects
local c1_`reg' = 1 // quarterly dummies
local c2_`reg' = 1 // per pupil expenditures 
local c3_`reg' = 1 // property taxes 
local c4_`reg' = 1 // demographics 
local c5_`reg' = 1 // parcel I controls 
local c6_`reg' = 1 // parcel II controls 
local c7_`reg' = 1 // interior dummy
restore

**************************************************************************************************************
* BUILD REGRESSION TABLE
**************************************************************************************************************

/*Generate variables for table*/
clear
gen var = ""
gen temp = ""
forvalues x = 1/8 {
	gen reg_`x' = . 
}

/*Set the number of observations*/
set obs 53

/*Fill in variable and control labels*/
#delimit ;
local list1 `""d_wrluri_int" "d_int_pp_expend" "d_int_ptax" "d_int_black" "d_int_asian" "d_int_edu_hs" 
	"d_int_edu_bs" "d_int_med_hh_inc" "land" "landsq" "log_cbd_dist" "log_cbd_dist2" "us990_tri" 
	"us990_tri_5km" "us990_tri_10km" "emp94" "emp94_5km" "emp94_10km" "dev90" "dev90_5km" "dev90_10km"  
	"int_flag""';
local list2 `""Municipality-border FE" "Quarter dummies" "Per pupil expenditures" "Property taxes per acre" 
	"Demographics" "Parcel controls I" "Parcel controls II"  "Interior dummy""';
#delimit cr
forvalues x = 1/1 {
	replace var = "WRLURI 1km (.5>x>.25, .25>x>0)" in `x' 
}
local i = 1
forvalues x = 2(2)44 {
	local name1 : word `i' of `list1'
	replace var = "`name1'" in `x'
	local i = `i' + 1
}
local i = 1
forvalues x = 46/53 {
	local name2 : word `i' of `list2'
	replace var = "`name2'" in `x' 
	local i = `i' + 1
}

/*Fill in temporary control variables*/
local list1 `""fe" "c1" "c2" "c3" "c4" "c5" "c6" "c7""'
local i = 1
forvalues x = 46/53 {
	local name1 : word `i' of `list1'
	replace temp = "`name1'" in `x'
	local i = `i' + 1
}

/*Fill in the table*/
local N = _N
forvalues reg = 1/8 {
	foreach var in d_wrluri_int d_int_pp_expend d_int_ptax $ex_demo $parcel1 $parcel2 int_flag {
		forvalues x = 1/`N' {
			if "`var'" == var[`x'] {
				local y = `x' + 1
				capture replace reg_`reg' = `b_`reg'_`var'' in `x' 
				capture replace reg_`reg' = `sd_`reg'_`var'' in `y' 
			}
		}
	}
	foreach control in fe c1 c2 c3 c4 c5 c6 c7 {
		forvalues x = 1/`N' {
			if "`control'" == temp[`x'] {
				capture replace reg_`reg' = ``control'_`reg'' in `x' 
			}
		}
	}
}

/*Convert variables to strings and round*/
forvalues x = 1/8 {
	tostring reg_`x', replace force format(%10.2f)
}

/*Add in significance stars*/
local N = _N
forvalues reg = 1/8 {
	foreach var in d_wrluri_int d_int_pp_expend d_int_ptax $ex_demo $parcel1 $parcel2 int_flag {
		forvalues x = 1/45 {
			if "`var'" == var[`x'] {	
				local y = `x' + 1
				local sd = reg_`reg'[`y'] 
				capture local p = `p_`reg'_`var''
				if `p' > 0.1 {
					capture replace reg_`reg' = "(" + "`sd'" + ")" in `y' 
				}
				if `p' <= 0.1 & `p' > 0.05 {
					local star "*"
					capture replace reg_`reg' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}
				if `p' <= 0.05 & `p' > 0.01 {
					local star "**"
					capture replace reg_`reg' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}	
				if `p' <= 0.01 { 
					local star "***"
					capture replace reg_`reg' = "(" + "`sd'" + ")" + "`star'" in `y' 
				}		
			}
		}
	}
}


/*Replace missing values with spaces*/
forvalues reg = 1/8 {
	replace reg_`reg' = "" if reg_`reg' == "." | reg_`reg' == "(.)" | reg_`reg' == "(.)*" | ///
		reg_`reg' == "(.)**" | reg_`reg' == "(.)***"
}	
		
/*Replace controls = 1 with controls = Y*/
local N = _N
forvalues reg = 1/8 {
	forvalues x = 46/`N' {
		if reg_`reg'[`x'] == "1.00" {
			replace reg_`reg' = "Y" in `x' 
		}
		if reg_`reg'[`x'] == "0.00" {
			replace reg_`reg' = "" in `x' 
		}
	}
}			

drop temp

export excel using tableA3_all_coefs_external.xls, replace

log close
